'''Test cases for QDeclarativeView'''

import unittest

from PySide.QtCore import QUrl, QObject, Property, Slot
from PySide.QtDeclarative import QDeclarativeView

from helper import adjust_filename, TimedQApplication

class MyObject(QObject):
    def __init__(self, text, parent=None):
        QObject.__init__(self, parent)
        self._text = text

    def getText(self):
        return self._text


    @Slot(str)
    def qmlText(self, text):
        self._qmlText = text

    title = Property(str, getText)


class TestQDeclarativeView(TimedQApplication):

    def testQDeclarativeViewList(self):
        view = QDeclarativeView()

        dataList = ["Item 1", "Item 2", "Item 3", "Item 4"]

        ctxt = view.rootContext()
        ctxt.setContextProperty("myModel", dataList)

        url = QUrl.fromLocalFile(adjust_filename('view.qml', __file__))
        view.setSource(url)
        view.show()

        self.assertEqual(view.status(), QDeclarativeView.Ready)


    def testModelExport(self):
        view = QDeclarativeView()
        dataList = [MyObject("Item 1"), MyObject("Item 2"), MyObject("Item 3"), MyObject("Item 4")]

        ctxt = view.rootContext()
        ctxt.setContextProperty("myModel", dataList)

        url = QUrl.fromLocalFile(adjust_filename('viewmodel.qml', __file__))
        view.setSource(url)
        view.show()

        self.assertEqual(view.status(), QDeclarativeView.Ready)


if __name__ == '__main__':
    unittest.main()



from PySide import QtGui, QtCore
from helper import UsesQApplication

import unittest

class MyWindow(QtGui.QMainWindow):
    appendText = QtCore.Signal(str)

    @QtCore.Slot()
    def onButtonPressed(self):
        self.appendText.emit("PySide")

    def __init__(self, parent=None):
        super(MyWindow, self).__init__(parent)

        self.textEdit = QtGui.QTextEdit()
        self.btn = QtGui.QPushButton("ClickMe")
        self.btn.clicked.connect(self.onButtonPressed)
        self.appendText.connect(self.textEdit.append)

    def start(self):
        self.btn.click()

    def text(self):
        return self.textEdit.toPlainText()


class testSignalWithCPPSlot(UsesQApplication):

    def testEmission(self):
        w = MyWindow()
        w.start()
        self.assertEqual(w.text(), "PySide")

if __name__ == '__main__':
    unittest.main()





'''Tests for QKeyEvent'''

import unittest

from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtTest import QTest

from helper import UsesQApplication


class KeyEventFilter(QObject):

    def __init__(self, widget, eventType, key):
        QObject.__init__(self)

        self.widget = widget
        self.eventType = eventType
        self.key = key

        self.processed = False

    def eventFilter(self, obj, event):
        if self.widget == obj and event.type() == self.eventType and \
               isinstance(event, QKeyEvent) and event.key() == self.key:
            self.processed = True
            return True

        return False

class EventFilterTest(UsesQApplication):

    def testKeyEvent(self):
        widget = QLineEdit()
        key = Qt.Key_A
        eventFilter = KeyEventFilter(widget, QEvent.KeyPress, key)
        widget.installEventFilter(eventFilter)

        QTest.keyClick(widget, key)

        self.assert_(eventFilter.processed)



if __name__ == '__main__':
    unittest.main()



import unittest

from helper import TimedQApplication
from PySide.QtGui import QPainter, QPushButton, QStyleOptionButton, QApplication, QStyle

class MyWidget(QPushButton):
    def __init__(self, parent = None):
        QPushButton.__init__(self, parent)
        self._painted = False

    def paintEvent(self, e):
        p = QPainter(self)
        style = QApplication.style()
        option = QStyleOptionButton()
        style.drawControl(QStyle.CE_PushButton, option, p)
        self._painted = True


class TestBug919(TimedQApplication):
    def testFontInfo(self):
        w = MyWidget()
        w.show()
        self.app.exec_()
        self.assert_(w._painted)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from sys import getrefcount
from PySide.QtCore import QObject

class DisconnectSignalsTest(unittest.TestCase):

    def setUp(self):
        self.emitter = QObject()

    def tearDown(self):
        del self.emitter

    def testConnectionRefCount(self):

        def destroyedSlot():
            pass

        self.assertEqual(getrefcount(destroyedSlot), 2)
        self.emitter.destroyed.connect(destroyedSlot)
        self.assertEqual(getrefcount(destroyedSlot), 3)
        self.emitter.destroyed.disconnect(destroyedSlot)
        self.assertEqual(getrefcount(destroyedSlot), 2)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
import unittest
from PySide.QtMaemo5 import QMaemo5ListPickSelector, QMaemo5ValueButton

from helper import UsesQApplication

class PickSelectorTest(UsesQApplication):
    def testOwnership(self):
        pickselector = QMaemo5ListPickSelector()
        button = QMaemo5ValueButton("test")
        button.setPickSelector(pickselector)
        del pickselector
        self.assert_(button.pickSelector())

if __name__ == '__main__':
    unittest.main()




''' Test bug 400: http://bugs.openbossa.org/show_bug.cgi?id=400'''

import unittest
from helper import UsesQApplication
from PySide.QtGui import QTreeWidgetItemIterator, QTreeWidgetItem, QTreeWidget

class BugTest(UsesQApplication):
    def testCase(self):
        treeWidget = QTreeWidget()
        treeWidget.setColumnCount(1)
        items = []
        for i in range(10):
            items.append(QTreeWidgetItem(None, ["item: %i" % i]))

        treeWidget.insertTopLevelItems(0, items);
        _iter = QTreeWidgetItemIterator(treeWidget)
        index = 0
        while(_iter.value()):
            item = _iter.value()
            self.assert_(item is items[index])
            index += 1
            _iter += 1


if __name__ == '__main__':
    unittest.main()



''' Test bug 662: http://bugs.openbossa.org/show_bug.cgi?id=662'''

import unittest
from PySide.QtGui import QTextEdit, QApplication, QTextCharFormat
import sys

class testQTextBlock(unittest.TestCase):
    def tesIterator(self):
        edit = QTextEdit()
        cursor = edit.textCursor()
        fmt = QTextCharFormat()
        frags = []
        for i in range(10):
            fmt.setFontPointSize(i+10)
            frags.append("block%d"%i)
            cursor.insertText(frags[i], fmt)

        doc = edit.document()
        block = doc.begin()

        index = 0
        for i in block:
            self.assertEqual(i.fragment().text(), frags[index])
            index += 1

if __name__ == '__main__':
    app = QApplication(sys.argv)
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *

class Mixin1(object):
    pass

class Mixin2(object):
    pass

class Mixin3(object):
    pass

class MainWindow(Mixin1, Mixin2, Mixin3, QFrame):
    def __init__(self):
        super(MainWindow, self).__init__()

def main():
    app = QApplication([])
    # if it doesn't crash it should pass
    w = MainWindow()
    w.show()
    QTimer.singleShot(0, w.close)
    app.exec_()

if __name__ == "__main__":
    main()





from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtDeclarative import *

from helper import adjust_filename
import unittest

paintCalled = False

class MetaA(type):
    pass

class A(object):
    __metaclass__ = MetaA

MetaB = type(QDeclarativeItem)
B = QDeclarativeItem

class MetaC(MetaA, MetaB):
    pass

class C(A, B):
    __metaclass__ = MetaC

class Bug825 (C):

    def __init__(self, parent = None):
        QDeclarativeItem.__init__(self, parent)
        # need to disable this flag to draw inside a QDeclarativeItem
        self.setFlag(QGraphicsItem.ItemHasNoContents, False)

    def paint(self, painter, options, widget):
        global paintCalled
        pen = QPen(Qt.black, 2)
        painter.setPen(pen);
        painter.drawPie(self.boundingRect(), 0, 128);
        paintCalled = True

class TestBug825 (unittest.TestCase):
    def testIt(self):
        global paintCalled
        app = QApplication([])
        qmlRegisterType(Bug825, 'bugs', 1, 0, 'Bug825')
        self.assertRaises(TypeError, qmlRegisterType, A, 'bugs', 1, 0, 'A')

        view = QDeclarativeView()
        view.setSource(QUrl.fromLocalFile(adjust_filename('bug_825.qml', __file__)))
        view.show()
        QTimer.singleShot(250, view.close)
        app.exec_()
        self.assertTrue(paintCalled)


if __name__ == '__main__':
    unittest.main()




import unittest

from helper import TimedQApplication
from PySide.QtGui import QIcon


class QIconCtorWithNoneTest(TimedQApplication):
    '''Test made by seblin, see Bug #944: http://bugs.pyside.org/show_bug.cgi?id=944'''

    def testQIconCtorWithNone(self):
        icon = QIcon(None)
        pixmap = icon.pixmap(48, 48)
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QObject
from testbinding import TestObject

class Receiver(QObject):

    def __init__(self):
        QObject.__init__(self)
        self.received = None

    def slot(self, value):
        self.received = value

class TypedefSignal(unittest.TestCase):

    def testTypedef(self):
        obj = TestObject(0)
        receiver = Receiver()

        obj.signalWithTypedefValue.connect(receiver.slot)
        obj.emitSignalWithTypedefValue(2)
        self.assertEqual(receiver.received.value, 2)

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtSql import *
import unittest

class TestBug1013 (unittest.TestCase):

    def someSlot(self, row, record):
        record.setValue(0, 2)
        self._wasCalled = True

    def testIt(self):
        app = QCoreApplication([])
        db = QSqlDatabase.addDatabase('QSQLITE')
        db.setDatabaseName(':memory:')
        db.open()
        query = QSqlQuery()
        query.exec_('CREATE TABLE "foo" (id INT);')
        model = QSqlTableModel()
        model.setTable('foo')

        self._wasCalled = False
        model.primeInsert.connect(self.someSlot)
        model.select()
        QTimer.singleShot(0,lambda: model.insertRow(0) and app.quit())
        app.exec_()
        self.assertTrue(self._wasCalled)
        self.assertEqual(model.data(model.index(0, 0)), 2)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python
'''Test cases for QThread'''

import unittest
from PySide.QtCore import QThread, QCoreApplication, QObject, SIGNAL, QMutex, QTimer
from PySide.QtCore import QEventLoop

from helper import UsesQCoreApplication

mutex = QMutex()

class Dummy(QThread):
    '''Dummy thread'''
    def __init__(self, *args):
        super(Dummy, self).__init__(*args)
        self.called = False

    def run(self):
        #Start-quit sequence
        self.qobj = QObject()
        mutex.lock()
        self.called = True
        mutex.unlock()

class QThreadSimpleCase(UsesQCoreApplication):

    def setUp(self):
        UsesQCoreApplication.setUp(self)
        self.called = False

    def tearDown(self):
        UsesQCoreApplication.tearDown(self)

    def testThread(self):
        #Basic QThread test
        obj = Dummy()
        obj.start()
        obj.wait()

        self.assert_(obj.called)

    def cb(self, *args):
        self.called = True
        #self.exit_app_cb()

    def abort_application(self):
        self._thread.terminate()
        self.app.quit()

    def testSignalFinished(self):
        #QThread.finished() (signal)
        obj = Dummy()
        QObject.connect(obj, SIGNAL('finished()'), self.cb)
        mutex.lock()
        obj.start()
        mutex.unlock()

        self._thread = obj
        QTimer.singleShot(1000, self.abort_application)
        self.app.exec_()

        self.assert_(self.called)

    def testSignalStarted(self):
        #QThread.started() (signal)
        obj = Dummy()
        QObject.connect(obj, SIGNAL('started()'), self.cb)
        obj.start()

        self._thread = obj
        QTimer.singleShot(1000, self.abort_application)
        self.app.exec_()

        self.assertEqual(obj.qobj.thread(), obj) # test QObject.thread() method
        self.assert_(self.called)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test cases for QDate'''

import unittest

from PySide.QtCore import *

class TestQDate (unittest.TestCase):
    def testGetDate(self):
        date = QDate(2009, 22, 9)
        tuple_ = date.getDate()
        self.assertEquals(tuple, tuple_.__class__)
        (y, m, d) = tuple_
        self.assertEqual(date.year(), y)
        self.assertEqual(date.month(), m)
        self.assertEqual(date.day(), d)

    def testGetWeekNumber(self):
        date = QDate(2000, 1, 1)
        tuple_ = date.weekNumber()
        self.assertEquals(tuple, tuple_.__class__)
        (week, yearNumber) = tuple_
        self.assertEqual(week, 52)
        self.assertEqual(yearNumber, 1999)

    def testBooleanCast(self):
        today = QDate.currentDate()
        self.assertTrue(today)
        nodate = QDate()
        self.assertFalse(nodate)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

'''Test cases for QResource usage'''

import unittest
from helper import adjust_filename
from PySide.QtCore import QFile, QIODevice
import resources_mc

class ResourcesUsage(unittest.TestCase):
    '''Test case for resources usage'''

    def testPhrase(self):
        #Test loading of quote.txt resource
        f = open(adjust_filename('quoteEnUS.txt', __file__), "r")
        orig = f.read()
        f.close()

        f = QFile(':/quote.txt')
        f.open(QIODevice.ReadOnly) #|QIODevice.Text)
        print("Error:", f.errorString())
        copy = f.readAll()
        f.close()
        self.assertEqual(orig, copy)

    def testImage(self):
        #Test loading of sample.png resource
        f = open(adjust_filename('sample.png', __file__), "rb")
        orig = f.read()
        f.close()

        f = QFile(':/sample.png')
        f.open(QIODevice.ReadOnly)
        copy = f.readAll()
        f.close()
        self.assertEqual(len(orig), len(copy))
        self.assertEqual(orig, copy)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

import unittest
from testbinding import TestObject
from PySide.QtGui import QApplication

class QApplicationInstance(unittest.TestCase):

    def appDestroyed(self):
        sefl.assert_(False)

    def testInstanceObject(self):
        TestObject.createApp()
        app1 = QApplication.instance()
        app2 = QApplication.instance()
        app1.setObjectName("MyApp")
        self.assertEqual(app1, app2)
        self.assertEqual(app2.objectName(), app1.objectName())
        app1.destroyed.connect(self.appDestroyed)

if __name__ == '__main__':
    unittest.main()




# Test case for PySide bug 634
# http://bugs.pyside.org/show_bug.cgi?id=634
# Marcus Lindblom <macke@yar.nu>; 2011-02-16

import unittest
from PySide.QtCore import QCoreApplication

class Mock(object):
    def __init__(self):
        self.called = False
        self.return_value = None

    def __call__(self, *args, **kwargs):
        self.called = True
        return self.return_value


class MockClassTest(unittest.TestCase):
    def testMockQCoreApplication(self):
        mock = Mock()
        setattr(QCoreApplication, 'instance', mock)
        QCoreApplication.instance()
        self.assert_(mock.called)

if __name__ == '__main__':
    unittest.main()





import unittest
import sys

from PySide.QtGui import QApplication, QPushButton, QWidget, QSpinBox

class QApplicationDelete(unittest.TestCase):
    '''Test for segfault when deleting a QApplication before a QWidget'''

    def testQPushButton(self):
        #QApplication deleted before QPushButton
        a = QApplication([])
        b = QPushButton('aaaa')
        del a

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

"""Tests covering signal emission and receiving to python slots"""

import sys
import unittest
import functools

from PySide.QtCore import QObject, SIGNAL, SLOT, QProcess, QTimeLine

from helper import BasicPySlotCase, UsesQCoreApplication


class ArgsOnEmptySignal(UsesQCoreApplication):
    '''Trying to emit a signal without arguments passing some arguments'''

    def testArgsToNoArgsSignal(self):
        '''Passing arguments to a signal without arguments'''
        process = QProcess()
        self.assertRaises(TypeError, process.emit, SIGNAL('started()'), 42)


class MoreArgsOnEmit(UsesQCoreApplication):
    '''Trying to pass more args than needed to emit (signals with args)'''

    def testMoreArgs(self):
        '''Passing more arguments than needed'''
        process = QProcess()
        self.assertRaises(TypeError, process.emit, SIGNAL('finished(int)'), 55, 55)

class Dummy(QObject):
    '''Dummy class'''
    pass

class PythonSignalToCppSlots(UsesQCoreApplication):
    '''Connect python signals to C++ slots'''

    def testWithoutArgs(self):
        '''Connect python signal to QTimeLine.toggleDirection()'''
        timeline = QTimeLine()
        dummy = Dummy()
        QObject.connect(dummy, SIGNAL('dummy()'),
                        timeline, SLOT('toggleDirection()'))

        orig_dir = timeline.direction()
        dummy.emit(SIGNAL('dummy()'))
        new_dir = timeline.direction()

        if orig_dir == QTimeLine.Forward:
            self.assertEqual(new_dir, QTimeLine.Backward)
        else:
            self.assertEqual(new_dir, QTimeLine.Forward)

    def testWithArgs(self):
        '''Connect python signals to QTimeLine.setCurrentTime(int)'''
        timeline = QTimeLine()
        dummy = Dummy()

        QObject.connect(dummy, SIGNAL('dummy(int)'),
                        timeline, SLOT('setCurrentTime(int)'))

        current = timeline.currentTime()
        dummy.emit(SIGNAL('dummy(int)'), current+42)
        self.assertEqual(timeline.currentTime(), current+42)

class CppSignalsToCppSlots(UsesQCoreApplication):
    '''Connection between C++ slots and signals'''

    def testWithoutArgs(self):
        '''Connect QProcess.started() to QTimeLine.togglePaused()'''
        process = QProcess()
        timeline = QTimeLine()

        QObject.connect(process, SIGNAL('finished(int, QProcess::ExitStatus)'),
                        timeline, SLOT('toggleDirection()'))

        orig_dir = timeline.direction()

        process.start(sys.executable, ['-c', '"print 42"'])
        process.waitForFinished()

        new_dir = timeline.direction()

        if orig_dir == QTimeLine.Forward:
            self.assertEqual(new_dir, QTimeLine.Backward)
        else:
            self.assertEqual(new_dir, QTimeLine.Forward)

called = False
def someSlot(args=None):
    global called
    called = True

class DynamicSignalsToFuncPartial(UsesQCoreApplication):

    def testIt(self):
        global called
        called = False
        o = QObject()
        o.connect(o, SIGNAL("ASignal"), functools.partial(someSlot, "partial .."))
        o.emit(SIGNAL("ASignal"))
        self.assertTrue(called)

class EmitUnknownType(UsesQCoreApplication):
    def testIt(self):
        a = QObject()
        a.connect(SIGNAL('foobar(Dummy)'), lambda x: 42) # Just connect with an unknown type
        self.assertRaises(TypeError, a.emit, SIGNAL('foobar(Dummy)'), 22)

class EmitEnum(UsesQCoreApplication):
    """Test emission of enum arguments"""

    def slot(self, arg):
        self.arg = arg

    def testIt(self):
        self.arg = None
        p = QProcess()
        p.stateChanged.connect(self.slot)
        p.stateChanged.emit(QProcess.NotRunning)
        self.assertEqual(self.arg, QProcess.NotRunning)

if __name__ == '__main__':
    unittest.main()



import unittest
import sys

from helper import UsesQApplication
from PySide.QtCore import QObject, QEvent
from PySide.QtGui import QWidget

class MyFilter(QObject):
  def eventFilter(self, obj, event):
    if event.type() == QEvent.KeyPress:
      pass
    return QObject.eventFilter(self, obj, event)


class EventFilter(UsesQApplication):
    def testRefCount(self):
        o = QObject()
        filt = MyFilter()
        o.installEventFilter(filt)
        self.assertEqual(sys.getrefcount(o), 2)

        o.installEventFilter(filt)
        self.assertEqual(sys.getrefcount(o), 2)

        o.removeEventFilter(filt)
        self.assertEqual(sys.getrefcount(o), 2)

    def testObjectDestructorOrder(self):
        w = QWidget()
        filt = MyFilter()
        filt.app = self.app
        w.installEventFilter(filt)
        w.show()
        w.close()
        w = None
        self.assert_(True)

if __name__ == '__main__':
    unittest.main()




'''Test cases for passing invalid callbacks to QObject.connect'''

import unittest

from PySide.QtCore import QObject, SIGNAL

class InvalidCallback(unittest.TestCase):
    '''Test case for passing an invalid callback to QObject.connect'''

    def setUp(self):
        #Acquire resources
        self.obj = QObject()

    def tearDown(self):
        #Release resources
        try:
            del self.obj
        except AttributeError:
            pass

    def testIntegerCb(self):
        #Test passing an int as callback to QObject.connect
        self.assertRaises(TypeError, QObject.connect, self.obj,
                            SIGNAL('destroyed()'), 42)

if __name__ == '__main__':
    unittest.main()





'''(Very) Simple test case for missing names from QtCore'''

import unittest
from PySide import QtCore

class MissingClasses(unittest.TestCase):

    def testQSettings(self): # Bug 232
        getattr(QtCore, 'QSettings')

    def testQtTrNoop(self): # Bug 220
        getattr(QtCore, 'QT_TR_NOOP')

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest

from PySide.QtGui import QWidget, QVBoxLayout, QPushButton, QApplication, QHBoxLayout
from helper import UsesQApplication

class QWidgetTest(UsesQApplication):

    def test_setLayout(self):
        layout = QVBoxLayout()
        btn1 = QPushButton("button_v1")
        layout.addWidget(btn1)

        btn2 = QPushButton("button_v2")
        layout.addWidget(btn2)

        layout2 = QHBoxLayout()

        btn1 = QPushButton("button_h1")
        layout2.addWidget(btn1)

        btn2 = QPushButton("button_h2")
        layout2.addWidget(btn2)

        layout.addLayout(layout2)

        widget = QWidget()
        widget.setLayout(layout)

if __name__ == '__main__':
    unittest.main()





''' Test bug 243: http://bugs.openbossa.org/show_bug.cgi?id=243'''

import unittest
import sys

from PySide.QtGui import QApplication, QMainWindow, QLayout

class QAppPresence(unittest.TestCase):

    def testBug(self):
        app = QApplication(sys.argv)
        window = QMainWindow()
        l = window.layout()
        self.assert_(isinstance(l, QLayout))

if __name__ == '__main__':
    unittest.main()



from PySide import QtCore, QtGui
import sys

class Test(QtGui.QGraphicsView):
    def __init__(self, parent=None):
        super(Test, self).__init__(parent)
        self.s = QtGui.QGraphicsScene()
        self.setScene(self.s)

a = QtGui.QApplication(sys.argv)
t = Test()
t.show()
QtCore.QTimer.singleShot(0, t.close)
sys.exit(a.exec_())



import unittest

from PySide.QtCore import *
from PySide.QtNetwork import *

from helper import UsesQCoreApplication
from httpd import TestServer

class testAuthenticationSignal(UsesQCoreApplication):

    def setUp(self):
        super(testAuthenticationSignal, self).setUp()
        self.httpd = TestServer(secure=True)
        self.httpd.start()
        self._resultOk = False

    def tearDown(self):
        if self.httpd:
            self.httpd.shutdown()
            del self.httpd
        super(testAuthenticationSignal, self).tearDown()

    def goAway(self):
        self.httpd.shutdown()
        self.app.quit()
        self.httpd = None

    def onAuthRequest(self, hostname, port, auth):
        self.assertTrue(isinstance(auth, QAuthenticator))
        self._resultOk = True
        self.goAway()

    def testwaitSignal(self):
        http = QHttp('127.0.0.1', self.httpd.port())
        http.connect(SIGNAL("authenticationRequired(const QString&, quint16, QAuthenticator*)"), self.onAuthRequest)
        path = QUrl.toPercentEncoding("/index.html", "!$&'()*+,;=:@/")
        data = http.get(str(path))
        self.app.exec_()
        self.assertTrue(self._resultOk)

    def testwaitSignal2(self):
        http = QHttp('127.0.0.1', self.httpd.port())
        # Using new signal slot syntax causes a segfault
        http.authenticationRequired.connect(self.onAuthRequest)
        path = QUrl.toPercentEncoding("/index.html", "!$&'()*+,;=:@/")
        data = http.get(str(path))
        self.app.exec_()
        self.assertTrue(self._resultOk)

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *
from PySide.QtGui import *

def foo(a, b):
    pass

class TestBug941 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])
        view = QHeaderView(Qt.Horizontal)
        self.assertTrue(view.sortIndicatorChanged.connect(foo))
        view.sortIndicatorChanged.emit(0, Qt.Vertical) # this can't raise an exception!

if __name__ == '__main__':
    unittest.main()



import sys

import unittest
from PySide.QtGui import QApplication, QStandardItemModel, QStandardItem, QItemSelection

class Bug324(unittest.TestCase):
    def testOperators(self):
        model = QStandardItemModel()
        for i in range(100):
            model.appendRow(QStandardItem("Item: %d"%i))

        first = model.index(0, 0)
        second = model.index(10, 0)
        third = model.index(20, 0)
        fourth = model.index(30, 0)

        sel = QItemSelection(first, second)
        sel2 = QItemSelection()
        sel2.select(third, fourth)

        sel3 = sel + sel2 #check operator +
        self.assertEqual(len(sel3), 2)
        sel4 = sel
        sel4 += sel2 #check operator +=
        self.assertEqual(len(sel4), 2)
        self.assertEqual(sel4, sel3)

if __name__ == "__main__":
    unittest.main()



from PySide import QtCore, QtGui

class Window(QtGui.QMainWindow):
    def childEvent(self, event):
        super(Window, self).childEvent(event)

app = QtGui.QApplication([])
window = Window()

dock1 = QtGui.QDockWidget()
dock2 = QtGui.QDockWidget()
window.addDockWidget(QtCore.Qt.LeftDockWidgetArea, dock1)
window.addDockWidget(QtCore.Qt.LeftDockWidgetArea, dock2)
window.tabifyDockWidget(dock1, dock2)

window.show()
QtCore.QTimer.singleShot(0, window.close)
app.exec_()




import sys
import unittest
from functools import partial

from PySide.QtCore import QObject, SIGNAL, QProcess

from helper import BasicPySlotCase, UsesQCoreApplication


class MultipleSignalConnections(unittest.TestCase):
    '''Base class for multiple signal connection testing'''

    def run_many(self, sender, signal, emitter, receivers, args=None):
        """Utility method to connect a list of receivers to a signal.
        sender - QObject that will emit the signal
        signal - string with the signal signature
        emitter - the callable that will trigger the signal
        receivers - list of BasicPySlotCase instances
        args - tuple with the arguments to be sent.
        """

        if args is None:
            args = tuple()
        for rec in receivers:
            rec.setUp()
            self.assert_(QObject.connect(sender, SIGNAL(signal), rec.cb))
            rec.args = tuple(args)

        emitter(*args)

        for rec in receivers:
            self.assert_(rec.called)


class PythonMultipleSlots(UsesQCoreApplication, MultipleSignalConnections):
    '''Multiple connections to python signals'''

    def testPythonSignal(self):
        """Multiple connections to a python signal (short-circuit)"""

        class Dummy(QObject):
            pass

        sender = Dummy()
        receivers = [BasicPySlotCase() for x in range(10)]
        self.run_many(sender, 'foobar', partial(sender.emit,SIGNAL('foobar')), receivers, (0, ))


class QProcessMultipleSlots(UsesQCoreApplication, MultipleSignalConnections):
    '''Multiple connections to QProcess signals'''

    def testQProcessStarted(self):
        '''Multiple connections to QProcess.started()'''
        sender = QProcess()
        receivers = [BasicPySlotCase() for x in range(10)]

        def start_proc(*args):
            sender.start(sys.executable, ['-c', '""'])
            sender.waitForFinished()

        self.run_many(sender, 'started()', start_proc, receivers)

    def testQProcessFinished(self):
        '''Multiple connections to QProcess.finished(int)'''
        sender = QProcess()
        receivers = [BasicPySlotCase() for x in range(10)]

        def start_proc(*args):
            sender.start(sys.executable, ['-c', '""'])
            sender.waitForFinished()

        self.run_many(sender, 'finished(int)', start_proc, receivers, (0,))

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *
from testbinding import TestObject


class Foo(QObject):
    bar = Signal()

class TestDisconnect(unittest.TestCase):
    def theSlot1(self):
        self.called1 = True

    def theSlot2(self):
        self.called2 = True

    def testIt(self):
        self.called1 = False
        self.called2 = False
        f = Foo()
        f.bar.connect(self.theSlot1)
        f.bar.connect(self.theSlot2)
        f.bar.emit()
        self.assertTrue(self.called1)
        self.assertTrue(self.called2)

        self.called1 = False
        self.called2 = False
        f.bar.disconnect()
        f.bar.emit()
        self.assertFalse(self.called1)
        self.assertFalse(self.called2)

    def testDuringCallback(self):
        """ Test to see if the C++ object for a connection is accessed after the
        method returns.  This causes a segfault if the memory that was used by the
        C++ object has been reused. """

        self.called = False
        obj = TestObject(0)
        def callback():
            obj.signalWithDefaultValue.disconnect(callback)

            # Connect more callbacks to try to overwrite memory
            for i in range(1000):
                obj.signalWithDefaultValue.connect(lambda: None)

            self.called = True

            # A non-None return value is needed
            return True
        obj.signalWithDefaultValue.connect(callback)
        obj.signalWithDefaultValue.emit()
        self.assert_(self.called)


if __name__ == '__main__':
    unittest.main()




''' Test the presence of X11 symbols in QtGui'''

import unittest

from PySide.QtGui import *

class X11Test(unittest.TestCase):

    def test(self):
        qpixmapFuncs = dir(QPixmap)
        self.assert_('handle' in qpixmapFuncs)
        self.assert_('x11Info' in qpixmapFuncs)
        self.assert_('x11PictureHandle' in qpixmapFuncs)
        self.assert_('x11SetDefaultScreen' in qpixmapFuncs)

    def testX11Functions(self):
        qx11infoFuncs = dir(QX11Info)
        self.assert_('display' in qx11infoFuncs)
        self.assert_('appVisual' in qx11infoFuncs)
        self.assert_('visual' in qx11infoFuncs)

if __name__ == '__main__':
    unittest.main()



'''Test bug 585: http://bugs.openbossa.org/show_bug.cgi?id=585'''

from PySide import QtCore ,QtGui
import sys
import unittest


class Bug585(unittest.TestCase):
    def testCase(self):
        app = QtGui.QApplication([])
        self._tree = QtGui.QTreeWidget()
        self._tree.setColumnCount(2)
        i1 = QtGui.QTreeWidgetItem(self._tree, ['1', ])
        i2 = QtGui.QTreeWidgetItem(self._tree, ['2', ])
        refCount = sys.getrefcount(i1)

        # this function return None
        # because the topLevelItem does not has a parent item
        # but still have a TreeWidget as a parent
        self._tree.topLevelItem(0).parent()

        self.assertEqual(refCount, sys.getrefcount(i1))

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# This file is part of the Shiboken Python Bindings Generator project.
#
# Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
#
# Contact: PySide team <contact@pyside.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# version 2.1 as published by the Free Software Foundation. Please
# review the following information to ensure the GNU Lesser General
# Public License version 2.1 requirements will be met:
# http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
# #
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA

import sys
import unittest

from helper import UsesQApplication
from PySide.QtGui import QMainWindow, QMenu, QApplication

class MainWindow(QMainWindow):
    def __init__(self, *args):
        self._menu = QMenu(self.dontexist) # attribute called with invalid C++ object

class MainWindow2(QMainWindow):
    def __init__(self):
        self.show()

class Bug696(UsesQApplication):
    def testContructorInitialization(self):
        self.assertRaises(AttributeError, MainWindow)

    def testContructorInitializationAndCPPFunction(self):
        self.assertRaises(RuntimeError, MainWindow2)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python

"""Tests covering signal emission and receiving to python slots"""

import unittest

from PySide.QtCore import QObject, SIGNAL, SLOT

try:
    from PySide.QtGui import QSpinBox, QPushButton
    hasQtGui = True
except ImportError:
    hasQtGui = False

from helper import BasicPySlotCase, UsesQApplication

if hasQtGui:
    class ButtonPySlot(UsesQApplication, BasicPySlotCase):
        """Tests the connection of python slots to QPushButton signals"""

        def testButtonClicked(self):
            """Connection of a python slot to QPushButton.clicked()"""
            button = QPushButton('Mylabel')
            QObject.connect(button, SIGNAL('clicked()'), self.cb)
            self.args = tuple()
            button.emit(SIGNAL('clicked(bool)'), False)
            self.assert_(self.called)

        def testButtonClick(self):
            """Indirect qt signal emission using the QPushButton.click() method """
            button = QPushButton('label')
            QObject.connect(button, SIGNAL('clicked()'), self.cb)
            self.args = tuple()
            button.click()
            self.assert_(self.called)


if hasQtGui:
    class SpinBoxPySlot(UsesQApplication, BasicPySlotCase):
        """Tests the connection of python slots to QSpinBox signals"""

        def setUp(self):
            super(SpinBoxPySlot, self).setUp()
            self.spin = QSpinBox()

        def tearDown(self):
            del self.spin
            super(SpinBoxPySlot, self).tearDown()

        def testSpinBoxValueChanged(self):
            """Connection of a python slot to QSpinBox.valueChanged(int)"""
            QObject.connect(self.spin, SIGNAL('valueChanged(int)'), self.cb)
            self.args = [3]
            self.spin.emit(SIGNAL('valueChanged(int)'), *self.args)
            self.assert_(self.called)

        def testSpinBoxValueChangedImplicit(self):
            """Indirect qt signal emission using QSpinBox.setValue(int)"""
            QObject.connect(self.spin, SIGNAL('valueChanged(int)'), self.cb)
            self.args = [42]
            self.spin.setValue(self.args[0])
            self.assert_(self.called)

        def atestSpinBoxValueChangedFewArgs(self):
            """Emission of signals with fewer arguments than needed"""
            # XXX: PyQt4 crashes on the assertRaises
            QObject.connect(self.spin, SIGNAL('valueChanged(int)'), self.cb)
            self.args = (554,)
            self.assertRaises(TypeError, self.spin.emit, SIGNAL('valueChanged(int)'))

if hasQtGui:
    class QSpinBoxQtSlots(UsesQApplication):
        """Tests the connection to QSpinBox qt slots"""

        qapplication = True

        def testSetValueIndirect(self):
            """Indirect signal emission: QSpinBox using valueChanged(int)/setValue(int)"""
            spinSend = QSpinBox()
            spinRec = QSpinBox()

            spinRec.setValue(5)

            QObject.connect(spinSend, SIGNAL('valueChanged(int)'), spinRec, SLOT('setValue(int)'))
            self.assertEqual(spinRec.value(), 5)
            spinSend.setValue(3)
            self.assertEqual(spinRec.value(), 3)
            self.assertEqual(spinSend.value(), 3)

        def testSetValue(self):
            """Direct signal emission: QSpinBox using valueChanged(int)/setValue(int)"""
            spinSend = QSpinBox()
            spinRec = QSpinBox()

            spinRec.setValue(5)
            spinSend.setValue(42)

            QObject.connect(spinSend, SIGNAL('valueChanged(int)'), spinRec, SLOT('setValue(int)'))
            self.assertEqual(spinRec.value(), 5)
            self.assertEqual(spinSend.value(), 42)
            spinSend.emit(SIGNAL('valueChanged(int)'), 3)

            self.assertEqual(spinRec.value(), 3)
            #Direct emission shouldn't change the value of the emitter
            self.assertEqual(spinSend.value(), 42)

            spinSend.emit(SIGNAL('valueChanged(int)'), 66)
            self.assertEqual(spinRec.value(), 66)
            self.assertEqual(spinSend.value(), 42)


if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *

class CoreApp(QCoreApplication):
    def __init__(self,*args):
        super(CoreApp,self).__init__(*args)
        # It shouldn't crash after the __init__ call

import sys
app = CoreApp(sys.argv)




'''Test cases for overriding inherited protected virtual methods'''

import unittest

from PySide.QtCore import QTimerEvent
from PySide.QtGui import QApplication, QSpinBox

from helper import UsesQApplication

class MySpinButton(QSpinBox):
    '''Simple example class of overriding QObject.timerEvent'''

    def __init__(self, max_runs=5, app=None):
        #Creates a new spinbox that will run <max_runs> and quit <app>
        super(MySpinButton, self).__init__()

        if app is None:
            app = QApplication([])

        self.app = app
        self.max_runs = max_runs
        self.runs = 0

    def timerEvent(self, event):
        #Timer event method
        self.runs += 1

        self.setValue(self.runs)

        if self.runs == self.max_runs:
            self.app.quit()

        if not isinstance(event, QTimerEvent):
            raise TypeError('Invalid event type. Must be TimerEvent')

class TimerEventTest(UsesQApplication):
    '''Test case for running QObject.timerEvent from inherited class'''

    qapplication = True

    def setUp(self):
        #Acquire resources
        super(TimerEventTest, self).setUp()
        self.widget = MySpinButton(app=self.app)

    def tearDown(self):
        #Release resources
        del self.widget
        super(TimerEventTest, self).tearDown()

    def testMethod(self):
        #QWidget.timerEvent overrinding (protected inherited)
        timer_id = self.widget.startTimer(0)

        self.app.exec_()

        self.widget.killTimer(timer_id)

        self.assert_(self.widget.runs >= self.widget.max_runs)


if __name__ == '__main__':
    unittest.main()
    #app = QApplication([])
    #widget  = MySpinButton(app=app)
    #widget.startTimer(500)
    #widget.show()
    #app.exec_()





import unittest

from PySide.QtGui import *
from helper import TimedQApplication

def makeBug643(tab):
    button = QPushButton('Foo')
    tab.insertTab(0, button, 'Foo')

class RemoveTabMethod(TimedQApplication):
    def setUp(self):
        TimedQApplication.setUp(self)
        self.tab = QTabWidget()

    def tearDown(self):
        del self.tab
        TimedQApplication.tearDown(self)


    def testRemoveTabPresence(self):
        self.assert_(getattr(self.tab, 'removeTab'))

    def testInsertTab(self):
        makeBug643(self.tab)
        self.assertEqual(self.tab.count(), 1)

if __name__ == '__main__':
    unittest.main()




'''Test cases for QWebPage'''

import unittest

from PySide.QtCore import QObject, SIGNAL, QUrl
from PySide.QtWebKit import QWebPage
from PySide.QtNetwork import QNetworkAccessManager

from helper import adjust_filename, TimedQApplication

#Define a global timeout because TimedQApplication uses a singleton!
#Use a value big enough to run all the tests.
TIMEOUT = 1000

class TestFindText(TimedQApplication):
    '''Test cases for finding text'''

    def setUp(self):
        TimedQApplication.setUp(self, timeout=TIMEOUT)
        self.page = QWebPage()
        QObject.connect(self.page, SIGNAL('loadFinished(bool)'),
                        self.load_finished)
        self.called = False

    def tearDown(self):
        #Release resources
        del self.page
        self.called = False
        TimedQApplication.tearDown(self)

    def testFindSelectText(self):
        url = QUrl.fromLocalFile(adjust_filename('fox.html', __file__))
        self.page.mainFrame().load(url)
        self.app.exec_()
        self.assert_(self.called)

    def load_finished(self, ok):
        #Callback to check if load was successful
        if ok:
            self.called = True
            self.assert_(self.page.findText('fox'))
            self.assertEqual(self.page.selectedText(), 'fox')
        self.app.quit()

class SetNetworkAccessManagerCase(TimedQApplication):

    def setUp(self):
        TimedQApplication.setUp(self, timeout=TIMEOUT)

    def testSetNetworkAccessManager(self):
        page = QWebPage()
        manager = QNetworkAccessManager()
        page.setNetworkAccessManager(manager)

    def testNetWorkAccessManager(self):
        page = QWebPage()
        a = page.networkAccessManager()

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import *

class MyDevice(QIODevice):
    def __init__(self, txt):
        QIODevice.__init__(self)
        self.txt = txt
        self.ptr = 0

    def readData(self, size):
        size = min(len(self.txt) - self.ptr, size)
        retval = self.txt[self.ptr:size]
        self.ptr += size
        return retval

class QIODeviceTest(unittest.TestCase):

    def testIt(self):
        device = MyDevice("hello world\nhello again")
        device.open(QIODevice.ReadOnly)

        s = QTextStream(device)
        self.assertEqual(s.readLine(), "hello world")
        self.assertEqual(s.readLine(), "hello again")

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide import QtCore
from helper import UsesQCoreApplication

class DerivedDate(QtCore.QDate):
    def __init__(self,y,m,d):
        super(DerivedDate,self).__init__(y,m,d)

class Emitter(QtCore.QObject):
    dateSignal1 = QtCore.Signal(QtCore.QDate)
    dateSignal2 = QtCore.Signal(DerivedDate)
    tupleSignal = QtCore.Signal(tuple)

class SignaltoSignalTest(UsesQCoreApplication):
    def myCb(self, dt):
        self._dt = dt

    def testBug(self):
        e = Emitter()
        d = DerivedDate(2010,8,24)
        self._dt = None
        e.dateSignal1.connect(self.myCb)
        e.dateSignal1.emit(d)
        self.assertEqual(self._dt, d)

        self._dt = None
        e.dateSignal2.connect(self.myCb)
        e.dateSignal2.emit(d)
        self.assertEqual(self._dt, d)

        myTuple = (5, 6, 7)
        self._dt = None
        e.tupleSignal.connect(self.myCb)
        e.tupleSignal.emit(myTuple)
        self.assertEqual(myTuple, self._dt)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide.QtCore import QObject, QCoreApplication, QTimeLine, Signal, Slot
from helper import UsesQCoreApplication

class ExtQObject(QObject):
    signalbetween = Signal('qreal')

    def __init__(self):
        QObject.__init__(self)
        self.counter = 0

    @Slot('qreal')
    def foo(self, value):
        self.counter += 1


class SignaltoSignalTest(UsesQCoreApplication):

    def setUp(self):
        UsesQCoreApplication.setUp(self)
        self.receiver = ExtQObject()
        self.timeline = QTimeLine(100)

    def tearDown(self):
        del self.timeline
        del self.receiver
        UsesQCoreApplication.tearDown(self)

    def testSignaltoSignal(self):
        self.timeline.setUpdateInterval(10)

        self.timeline.finished.connect(self.app.quit)

        self.timeline.valueChanged.connect(self.receiver.signalbetween)
        self.receiver.signalbetween.connect(self.receiver.foo)

        self.timeline.start()

        self.app.exec_()

        self.assert_(self.receiver.counter > 1)


if __name__ == '__main__':
    unittest.main()




""" Unittest for bug #575 """
""" http://bugs.openbossa.org/show_bug.cgi?id=575 """

from PySide.QtGui import QApplication, QPlainTextEdit, QTextEdit
import sys
import unittest

class Bug575(unittest.TestCase):
    def testPropertyValues(self):
        app = QApplication(sys.argv)
        textEdit = QPlainTextEdit()
        textEdit.insertPlainText("PySide INdT")
        selection = QTextEdit.ExtraSelection()
        selection.cursor = textEdit.textCursor()
        selection.cursor.setPosition(2)
        self.assertEqual(selection.cursor.position(), 2)

if __name__ == '__main__':
    unittest.main()




import unittest

from helper import UsesQApplication
from PySide.QtCore import Qt, QTimer
from PySide.QtGui import QLabel, QPainter
from PySide.QtGui import QGraphicsScene, QGraphicsView, QGraphicsItem, QGraphicsProxyWidget

class QGraphicsProxyWidgetTest(UsesQApplication):
    def testQGraphicsProxyWidget(self):
        scene = QGraphicsScene()

        proxy = QGraphicsProxyWidget(None, Qt.Window)
        widget = QLabel('Widget')
        proxy.setWidget(widget)
        proxy.setCacheMode(QGraphicsItem.DeviceCoordinateCache)
        scene.addItem(proxy)
        scene.setSceneRect(scene.itemsBoundingRect())

        view = QGraphicsView(scene)
        view.setRenderHints(QPainter.Antialiasing|QPainter.SmoothPixmapTransform)
        view.setViewportUpdateMode(QGraphicsView.BoundingRectViewportUpdate)
        view.show()

        timer = QTimer.singleShot(100, self.app.quit)
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()




''' unit test for BUG #1069 '''

from PySide import QtCore
import unittest

class QDataStreamOpOverloadTestCase(unittest.TestCase):
    def setUp(self):
        self.ba = QtCore.QByteArray()
        self.stream = QtCore.QDataStream(self.ba, QtCore.QIODevice.WriteOnly)

    def testIt(self):
        self.stream << "hello"
        ok = False
        for c in self.ba:
            if c != b'\x00':
                ok = True
                break

        self.assertEqual(ok, True)

if __name__ == "__main__":
    unittest.main()



import unittest
from PySide.QtCore import *

class MyFileEngine (QAbstractFileEngine):

    def __init__(self):
        QAbstractFileEngine.__init__(self)
        self.contents = "Foo \0bar for the win!"
        self.pos = 0

    def open(self, mode):
        return True

    def read(self, maxlen):
        print("Reading... to return ", self.contents[self.pos:maxlen])

        if self.pos > len(self.contents):
            return -1

        res = self.contents[self.pos:maxlen]
        self.pos += len(res)
        return res

    def readLine(self, maxlen):
        return self.contents[self.pos:maxlen]

class MyFileEngineHandler (QAbstractFileEngineHandler):

    def create(self, fileName):
        if fileName.startswith("foo:/"):
            return MyFileEngine()
        return None


class TestBug723 (unittest.TestCase):

    def testIt(self):
        fh = MyFileEngineHandler()

        f = QFile("foo:/bar")

        print(type(QFile.ReadOnly))
        v = (QFile.ReadOnly | QFile.Text)
        print(type(v))

        """
        assert(f.open(QFile.ReadOnly | QFile.Text))
        contents = f.readAll()
        self.assertEqual(contents, "Foo \0bar for the win!")
        f.close()
        """


if __name__ == '__main__':
    unittest.main()




import unittest
from PySide import QtCore
import weakref

class LeakingSignal(unittest.TestCase):

    def testLeakingSignal(self):
        # Was segfaulting when the signal was garbage collected.
        class Emitter(QtCore.QObject):
            my_signal = QtCore.Signal(object)

        emitter = Emitter()

if __name__ == '__main__':
    unittest.main()




'''Tests for calling methods further than the direct parent'''

import unittest

from PySide.QtGui import QPushButton, QWidget

from helper import UsesQApplication

class Dummy(QPushButton):

    def show(self):
        QWidget.show(self)
        self.called = True

class GrandParentMethod(UsesQApplication):
    def testMethod(self):
        obj = Dummy()
        obj.show()
        self.assert_(obj.called)

if __name__ == '__main__':
    unittest.main()



import unittest
import sys
from PySide.QtGui import QWidget, QPushButton

from helper import UsesQApplication

class TestBug1002 (UsesQApplication):
    def testReturnWindow(self):
        widget = QWidget()
        button = QPushButton(widget)
        self.assertEqual(sys.getrefcount(widget), 2)
        window = button.window()
        self.assertEqual(sys.getrefcount(widget), 3)
        self.assertEqual(sys.getrefcount(window), 3)

        del widget

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtDeclarative import *

import sys

app = QApplication(sys.argv)

engine = QDeclarativeEngine()
component = QDeclarativeComponent(engine)

# This should segfault if the QDeclarativeComponent has not QDeclarativeEngine
component.loadUrl(QUrl.fromLocalFile('foo.qml'))




# -*- coding: utf-8 -*-

''' Test the QMenu.addAction() method'''

import unittest
import sys

from PySide import QtGui

from helper import UsesQApplication

class QMenuAddAction(UsesQApplication):

    def openFile(self, *args):
        self.arg = args

    def testQMenuAddAction(self):
        fileMenu = QtGui.QMenu("&File")

        addNewAction = fileMenu.addAction("&Open...", self.openFile)
        addNewAction.trigger()
        self.assertEquals(self.arg, ())

if __name__ == '__main__':
    unittest.main()



import PySide
import unittest

from PySide.QtCore import QByteArray, QDate, QDateTime, QTime, QLine, QLineF
from PySide.QtCore import Qt, QSize, QSizeF, QRect, QRectF, QPoint, QPointF
from PySide.QtCore import QUuid

class ReprCopyHelper:
    def testCopy(self):
        copy = eval(self.original.__repr__())
        self.assert_(copy is not self.original)
        self.assertEqual(copy, self.original)

class QByteArrayReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QByteArray('the quick brown fox jumps over the lazy dog')


class QDateReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QDate(2010, 11, 22)


class QTimeReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QTime(11, 37, 55, 692)


class QDateTimeReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QDateTime(2010, 5, 18, 10, 24, 45, 223, Qt.LocalTime)


class QSizeReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QSize(42, 190)


class QSizeFReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QSizeF(42.7, 190.2)

class QRectReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QRect(100, 200, 300, 400)

class QRectFReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QRectF(100.33, 200.254, 300.321, 400.123)

class QLineReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QLine(1, 2, 3, 4)

class QLineFReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QLineF(1.1, 2.2, 3.3, 4.4)

class QPointReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QPoint(1, 2)

class QPointFReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QPointF(1.1, 2.2)

class QUuiCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QUuid("67C8770B-44F1-410A-AB9A-F9B5446F13EE")

if __name__ == '__main__':
    unittest.main()




import sys
import unittest

from PySide.QtCore import QSignalMapper
from PySide.QtGui import QCheckBox

from helper import UsesQApplication

class MultipleSlotTest(UsesQApplication):
    def cb_changed(self, i):
        self._changed = True

    def cb_changedVoid(self):
        self._changed = True

    def testSignalMapper(self):
        checkboxMapper = QSignalMapper()
        box = QCheckBox('check me')
        box.stateChanged.connect(checkboxMapper.map)

        checkboxMapper.setMapping(box, box.text())
        checkboxMapper.mapped[str].connect(self.cb_changed)
        self._changed = False
        box.setChecked(True)
        self.assert_(self._changed)

    def testSimpleSignal(self):
        box = QCheckBox('check me')
        box.stateChanged[int].connect(self.cb_changedVoid)
        self._changed = False
        box.setChecked(True)
        self.assert_(self._changed)

if __name__ == '__main__':
    unittest.main()



''' Test bug 688: http://bugs.openbossa.org/show_bug.cgi?id=688'''

import unittest
from helper import UsesQApplication
from PySide.QtGui import QTextFrame, QTextEdit, QTextCursor, QTextCharFormat, QFont, QTextFrameFormat

class BugTest(UsesQApplication):
    def testCase(self):
        editor = QTextEdit()
        cursor = QTextCursor(editor.textCursor())
        cursor.movePosition(QTextCursor.Start)
   
        mainFrame = cursor.currentFrame()
        
        plainCharFormat = QTextCharFormat()
        boldCharFormat = QTextCharFormat()
        boldCharFormat.setFontWeight(QFont.Bold);
        cursor.insertText("""
                          Text documents are represented by the 
                          QTextDocument class, rather than by QString objects. 
                          Each QTextDocument object contains information about 
                          the document's internal representation, its structure, 
                          and keeps track of modifications to provide undo/redo 
                          facilities. This approach allows features such as the 
                          layout management to be delegated to specialized 
                          classes, but also provides a focus for the framework.""",
                          plainCharFormat)

        frameFormat = QTextFrameFormat()
        frameFormat.setMargin(32)
        frameFormat.setPadding(8)
        frameFormat.setBorder(4)
        cursor.insertFrame(frameFormat)

        cursor.insertText("""
                          Documents are either converted from external sources 
                          or created from scratch using Qt. The creation process 
                          can done by an editor widget, such as QTextEdit, or by 
                          explicit calls to the Scribe API.""",
                          boldCharFormat)

        cursor = mainFrame.lastCursorPosition()
        cursor.insertText("""
                          There are two complementary ways to visualize the 
                          contents of a document: as a linear buffer that is 
                          used by editors to modify the contents, and as an 
                          object hierarchy containing structural information 
                          that is useful to layout engines. In the hierarchical 
                          model, the objects generally correspond to visual 
                          elements such as frames, tables, and lists. At a lower 
                          level, these elements describe properties such as the 
                          style of text used and its alignment. The linear 
                          representation of the document is used for editing and 
                          manipulation of the document's contents.""",
                          plainCharFormat)

        
        frame = cursor.currentFrame()

        items = []

        #test iterator
        for i in frame:
            items.append(i)

        #test __iadd__
        b = frame.begin()
        i = 0
        while not b.atEnd():
            self.assertEqual(b, items[i])
            self.assert_(b.parentFrame(), items[i].parentFrame())
            b.__iadd__(1)
            i += 1

        #test __isub__
        b = frame.end()
        i = 0
        while i > 0:
            self.assertEqual(b, items[i])
            self.assert_(b.parentFrame(), items[i].parentFrame())
            b.__isub__(1)
            i -= 1

        

if __name__ == '__main__':
    unittest.main()




import unittest
import py3kcompat as py3k

from PySide import phonon

from helper import UsesQCoreApplication

class CapabilitiesTest(UsesQCoreApplication):
    def setUp(self):
        super(CapabilitiesTest, self).setUp()
        self.app.setApplicationName("Dummy")

    def tearDown(self):
        super(CapabilitiesTest, self).tearDown()


    def testExists(self):
        self.assertTrue(phonon.Phonon.BackendCapabilities)

    def testNotifierIdentity(self):
        # Notifier is a singleton
        self.assertEqual(phonon.Phonon.BackendCapabilities.notifier(),
                         phonon.Phonon.BackendCapabilities.notifier())

        self.assertTrue(phonon.Phonon.BackendCapabilities.notifier() is
                     phonon.Phonon.BackendCapabilities.notifier())

    def testDevices(self):
        # TODO Improve this test
        devices = phonon.Phonon.BackendCapabilities.availableAudioOutputDevices()
        for device in devices:
            self.assertTrue(isinstance(device, phonon.Phonon.AudioOutputDevice))

    def testMimeTypes(self):
        # TODO Improve this test
        mimeTypes = phonon.Phonon.BackendCapabilities.availableMimeTypes()
        for mime in mimeTypes:
            self.assertTrue(isinstance(mime, py3k.unicode))

    def testAudioEffects(self):
        # TODO Improve this test
        effects = phonon.Phonon.BackendCapabilities.availableAudioEffects()
        for effect in effects:
            self.assertTrue(isinstance(effect, phonon.Phonon.EffectDescription))

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

'''Test case for signal signature received by QObject::connectNotify().'''

import unittest
from PySide.QtCore import *
from helper import UsesQCoreApplication

class Obj(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.signal = ''

    def connectNotify(self, signal):
        self.signal = signal

def callback(arg=None):
    pass

class TestConnectNotifyWithNewStyleSignals(UsesQCoreApplication):
    '''Test case for signal signature received by QObject::connectNotify().'''

    def testOldStyle(self):
        sender = Obj()
        receiver = QObject()
        sender.connect(SIGNAL('destroyed()'), receiver, SLOT('deleteLater()'))
        self.assertEqual(sender.signal, SIGNAL('destroyed()'))

    def testOldStyleWithPythonCallback(self):
        sender = Obj()
        sender.connect(SIGNAL('destroyed()'), callback)
        self.assertEqual(sender.signal, SIGNAL('destroyed()'))

    def testNewStyle(self):
        sender = Obj()

        sender.destroyed.connect(callback)
        self.assertEqual(sender.signal, SIGNAL('destroyed()'))

        sender.destroyed[QObject].connect(callback)
        self.assertEqual(sender.signal, SIGNAL('destroyed(QObject*)'))

if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import QEvent
from PySide.QtGui import QColor
import unittest

class MyEvent(QEvent):
    def __init__(self):
        QEvent.__init__(self, QEvent.Type(999))


class Bug617(unittest.TestCase):
    def testRepr(self):
        c = QColor.fromRgb(1, 2, 3, 4)
        s = c.spec()
        self.assertEqual(repr(s), repr(QColor.Rgb))

    def testOutOfBounds(self):
        e = MyEvent()
        self.assertEqual(repr(e.type()), 'PySide.QtCore.QEvent.Type(999)')

if __name__ == "__main__":
   unittest.main()



#!/usr/bin/python
'''Test suite for QtCore.Qt namespace'''

import unittest

from PySide.QtCore import Qt

class QtNamespace(unittest.TestCase):
    '''Test case for accessing attributes from Qt namespace'''

    def testBasic(self):
        #Access to Qt namespace
        getattr(Qt, 'Horizontal')
        getattr(Qt, 'WindowMaximizeButtonHint')
        self.assert_(True)


if __name__ == '__main__':
    unittest.main()



import unittest
import PySide
from PySide.QtScript import *

from helper import UsesQApplication

class TestQScriptValue (UsesQApplication):

    def testOperator(self):
        engine = QScriptEngine()
        value = engine.evaluate('x = {"a": 1, "b":2}')
        self.assertEqual(value['a'], 1)
        self.assertRaises(KeyError, value.__getitem__, 'c')
        value = engine.evaluate('x = ["x", "y", "z"]')
        self.assertEqual(value[2], 'z')
        self.assertRaises(IndexError, value.__getitem__, 23)

    def testRepr(self):
        value = QScriptValue("somePerson = { firstName: 'John', lastName: 'Doe' }")
        value2 = eval(repr(value))
        self.assertEqual(value.toString(), value2.toString())
        self.assertEqual(value.toVariant(), value2.toVariant())

    def testIteratorProtocol(self):
        engine = QScriptEngine()
        value = engine.evaluate('x = {"a": 1, "b":2}')
        d = {}
        for k, v in QScriptValueIterator(value):
            d[k] = v
        self.assertEqual(d, {'a': 1, 'b': 2})

        d = {}
        for k, v in value:
            d[k] = v
        self.assertEqual(d, {'a': 1, 'b': 2})

if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtCore import QObject, Slot, QMetaObject

class MyObject(QObject):
    @Slot(int, str)
    def slot1(self, a, b):
        pass

class testAttribute(unittest.TestCase):
    def testBug896(self):
        mo = MyObject.staticMetaObject
        self.assertTrue(isinstance(mo, QMetaObject))
        self.assertEqual(mo.className(), 'MyObject')
        self.assertTrue(mo.indexOfSlot('slot1(int,QString)') > -1)

    def testDuplicateSlot(self):
        mo = MyObject.staticMetaObject
        self.assertEqual(mo.indexOfSignal('destroyed(void)'), -1)
        self.assertTrue(mo.indexOfSignal('destroyed()') > -1)

if __name__ == '__main__':
    unittest.main()



import unittest

from helper import UsesQApplication
from PySide.QtGui import QItemSelection, QStandardItemModel

class QItemSelectionTest(UsesQApplication):
    def testLen(self):
        model = QStandardItemModel(2, 2)
        model.insertRow(0)
        model.insertRow(1)
        model.insertColumn(0)
        model.insertColumn(1)
        selection = QItemSelection(model.index(0,0), model.index(1,1))
        self.assertEqual(len(selection), 1)

if __name__ == '__main__':
    unittest.main()





import unittest

import PySide
from PySide.QtCore import QPoint
from PySide.QtGui import QMatrix
from PySide.QtGui import QMatrix2x2, QMatrix2x3, QMatrix2x4
from PySide.QtGui import QMatrix3x2, QMatrix3x3, QMatrix3x4
from PySide.QtGui import QMatrix4x2, QMatrix4x3, QMatrix4x4
from PySide.QtGui import QVector2D, QVector3D, QVector4D
from PySide.QtGui import QColor, QTransform, QKeySequence, QQuaternion
from PySide.QtGui import QPolygon

class ReprCopyHelper:
    def testCopy(self):
        copy = eval(self.original.__repr__())
        self.assert_(copy is not self.original)
        self.assertEqual(copy, self.original)

class QTransformReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QTransform(1, 2, 3, 4, 5, 6, 7, 8)

class QKeySequenceReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QKeySequence("Ctrl+P")

class QQuaternionReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QQuaternion(1, 2, 3, 4)

class QVector2DReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QVector2D(1, 2)

class QVector3DReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QVector3D(1, 2, 3)

class QVector4DReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QVector4D(1, 2, 3, 4)

class QMatrixReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix(1, 2, 3, 4, 5, 6)


# Avoid these tests until get gcc fixed
# Related bug: http://gcc.gnu.org/bugzilla/show_bug.cgi?id=43247
"""
class QMatrix2x2ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix2x2([1, 2, 3, 4])

class QMatrix2x3ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix2x3([1, 2, 3, 4, 5, 6])

class QMatrix2x4ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix2x4([1, 2, 3, 4, 5, 6, 7, 8])

class QMatrix3x2ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix3x2([1, 2, 3, 4, 5, 6])

class QMatrix3x3ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix3x3([1, 2, 3, 4, 5, 6, 7, 8, 9])

class QMatrix3x4ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix3x4([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])

class QMatrix4x2ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix4x2([1, 2, 3, 4, 5, 6, 7, 8])

class QMatrix4x3ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix4x3([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])

class QMatrix4x4ReprCopy(ReprCopyHelper, unittest.TestCase):
    def setUp(self):
        self.original = QMatrix4x4([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16])
"""

if __name__ == '__main__':
    unittest.main()



import unittest
from PySide.QtCore import *

class TestBug699 (unittest.TestCase):

    def defClass(self):
        class Foo (QObject):
            def foo(self):
                pass

            prop = Property(foo, foo)

    def testIt(self):
        self.assertRaises(TypeError, self.defClass)

if __name__ == '__main__':
    unittest.main()




'''Test cases for QTCPServer'''

import unittest

from PySide.QtNetwork import QTcpServer

class ListenDefaultArgsCase(unittest.TestCase):
    '''Test case for TcpServer.listen with default args'''

    def setUp(self):
        #Acquire resources
        self.server = QTcpServer()

    def tearDown(self):
        #Release resources
        del self.server

    def testDefaultArgs(self):
        # @bug 108
        #Default arguments for QTcpServer.listen
        self.server.listen()

if __name__ == '__main__':
    unittest.main()



import unittest

import PySide
from PySide.QtGui import QVector2D, QVector3D, QVector4D
from PySide.QtGui import QColor

class testCases(unittest.TestCase):
    def testQVector2DToTuple(self):
        vec = QVector2D(1, 2)
        self.assertEqual((1, 2), vec.toTuple())

    def testQVector3DToTuple(self):
        vec = QVector3D(1, 2, 3)
        self.assertEqual((1, 2, 3), vec.toTuple())

    def testQVector4DToTuple(self):
        vec = QVector4D(1, 2, 3, 4)
        self.assertEqual((1, 2, 3, 4), vec.toTuple())

    def testQColorToTuple(self):
        c = QColor(0, 0, 255)
        c.setRgb(1, 2, 3)
        self.assertEqual((1, 2, 3, 255), c.toTuple())

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest, os
from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtSvg import *

class QSvgRendererTest(unittest.TestCase):

    def testLoad(self):
        tigerPath = os.path.join(os.path.dirname(__file__), 'tiger.svg')
        app = QApplication([])

        fromFile = QSvgRenderer(tigerPath)
        self.assertTrue(fromFile.isValid())

        tigerFile = QFile(tigerPath)
        tigerFile.open(QFile.ReadOnly)
        tigerData = tigerFile.readAll()
        fromContents = QSvgRenderer(tigerData)
        self.assertTrue(fromContents.isValid())

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python

import unittest
from PySide import QtCore

class Lock(QtCore.QMutex):
    def tryLock(self,timeoutt=10):
        return QtCore.QMutex.tryLock(self,timeoutt)

class TestBug(unittest.TestCase):

    def testCase(self):
        l = Lock()
        l.tryLock() # this cause a assertion


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest

from PySide.QtGui import QGraphicsScene, QGraphicsRectItem, QGraphicsView, QApplication, QBrush, QColor
from PySide.QtCore import QTimer
from helper import UsesQApplication

qgraphics_item_painted = False

class RoundRectItem(QGraphicsRectItem):

    def __init__(self, x, y, w, h):
        QGraphicsRectItem.__init__(self, x, y, w, h)

    def paint(self, painter, qstyleoptiongraphicsitem, qwidget):
        global qgraphics_item_painted
        qgraphics_item_painted = True


class QGraphicsItemTest(UsesQApplication):

    def createRoundRect(self, scene):
        item = RoundRectItem(10, 10, 100, 100)
        item.setBrush(QBrush(QColor(255, 0, 0)))
        scene.addItem(item)
        return item

    def quit_app(self):
        self.app.quit()

    def test_setParentItem(self):
        global qgraphics_item_painted

        scene = QGraphicsScene()
        scene.addText("test")
        view = QGraphicsView(scene)

        rect = self.createRoundRect(scene)
        view.show()
        QTimer.singleShot(1000, self.quit_app)
        self.app.exec_()
        self.assert_(qgraphics_item_painted)


if __name__ == '__main__':
    unittest.main()





'''Test cases for QHttp'''

import unittest

from PySide.QtCore import *
from PySide.QtMultimedia import *

class testAudioDevices(unittest.TestCase):

    def testListDevices(self):
        valid = False
        devices = QAudioDeviceInfo.availableDevices(QAudio.AudioOutput)
        if not len(devices):
            return

        valid = True
        for devInfo in devices:
            if devInfo.deviceName() == 'null':
                # skip the test if the only device found is a invalid device
                if len(devices) == 1:
                    return
                else:
                    continue
            fmt = QAudioFormat()
            for codec in devInfo.supportedCodecs():
                fmt.setCodec(codec)
                for frequency in devInfo.supportedFrequencies():
                    fmt.setFrequency(frequency)
                    for channels in devInfo.supportedChannels():
                        fmt.setChannels(channels)
                        for sampleType in devInfo.supportedSampleTypes():
                            fmt.setSampleType(sampleType)
                            for sampleSize in devInfo.supportedSampleSizes():
                                fmt.setSampleSize(sampleSize)
                                for endian in devInfo.supportedByteOrders():
                                    fmt.setByteOrder(endian)
                                    if devInfo.isFormatSupported(fmt):
                                        return
        self.assert_(False)


if __name__ == '__main__':
    unittest.main()



''' Test bug 367: http://bugs.openbossa.org/show_bug.cgi?id=467'''

import unittest
from helper import UsesQApplication
from PySide.QtGui import QMainWindow, QApplication

class MyWidget(QMainWindow):
    def __init__(self, parent = None):
        QMainWindow.__init__(self, parent)


class BugTest(UsesQApplication):
    def testCase(self):
        w = MyWidget()
        widgets = QApplication.allWidgets()
        self.assert_(w in widgets)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Test case for QObject.timerEvent overloading'''

import unittest
from time import sleep
from PySide.QtCore import QObject, QCoreApplication

from helper import UsesQCoreApplication

class Dummy(QObject):

    def __init__(self, app):
        super(Dummy, self).__init__()
        self.times_called = 0
        self.app = app

    def timerEvent(self, event):
        QObject.timerEvent(self, event)
        event.accept()
        self.times_called += 1

        if self.times_called == 5:
            self.app.exit(0)

class QObjectTimerEvent(UsesQCoreApplication):

    def setUp(self):
        #Acquire resources
        super(QObjectTimerEvent, self).setUp()

    def tearDown(self):
        #Release resources
        super(QObjectTimerEvent, self).tearDown()

    def testTimerEvent(self):
        #QObject.timerEvent overloading
        obj = Dummy(self.app)
        timer_id = obj.startTimer(200)
        self.app.exec_()
        obj.killTimer(timer_id)
        self.assertEqual(obj.times_called, 5)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# DBUS Client using PySide integration

import sys
from traceback import print_exc

# import python dbus module
import dbus
# import python dbus GLib mainloop support
import dbus.mainloop.glib
# import QtCore
from PySide.QtCore import *

# signal handler
def button_clicked():
    print "button clicked"

# main function
if __name__ == '__main__':

    # Enable glib main loop support
    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
    # Get the session bus
    bus = dbus.SessionBus()

    try:
        # Get the remote object
        remote_object = bus.get_object("com.example.SampleService",
                                       "/DBusWidget")
        # Get the remote interface for the remote object
        iface = dbus.Interface(remote_object, "com.example.SampleWidget")
    except dbus.DBusException:
        print_exc()
        sys.exit(1)

    # Start the application
    app = QCoreApplication([])

    # Call some methods of the remote interface
    iface.show()
    iface.setText("Emit signal")
    # connect the DBus signal clicked to the function button_clicked
    iface.connect_to_signal("clicked", button_clicked)
    iface.connect_to_signal("lastWindowClosed", app.quit)

    # enter in the main loop
    app.exec_()




'''Test cases for QLayout handling of child widgets references'''

import unittest
from sys import getrefcount

from PySide.QtGui import QHBoxLayout, QVBoxLayout, QGridLayout, QWidget
from PySide.QtGui import QStackedLayout, QFormLayout
from PySide.QtGui import QApplication, QPushButton, QLabel

from helper import UsesQApplication

class SaveReference(UsesQApplication):
    '''Test case to check if QLayout-derived classes increment the refcount
    of widgets passed to addWidget()'''

    # Adding here as nose can't see the qapplication attrib we inherit
    qapplication = True

    def setUp(self):
        #Acquire resources
        super(SaveReference, self).setUp()
        self.widget1 = QPushButton('click me')
        self.widget2 = QLabel('aaa')

    def tearDown(self):
        #Release resources
        del self.widget2
        del self.widget1
        super(SaveReference, self).tearDown()

    def checkLayoutReference(self, layout):
        #Checks the reference cound handling of layout.addWidget
        self.assertEqual(getrefcount(self.widget1), 2)
        layout.addWidget(self.widget1)
        self.assertEqual(getrefcount(self.widget1), 3)

        self.assertEqual(getrefcount(self.widget2), 2)
        layout.addWidget(self.widget2)
        self.assertEqual(getrefcount(self.widget2), 3)

        # Check if doesn't mess around with previous widget refcount
        self.assertEqual(getrefcount(self.widget1), 3)

    def testMoveLayout(self):
        l = QHBoxLayout()
        self.assertEqual(getrefcount(self.widget1), 2)
        l.addWidget(self.widget1)
        self.assertEqual(getrefcount(self.widget1), 3)

        w = QWidget()
        w.setLayout(l)
        self.assertEqual(getrefcount(self.widget1), 3)


    def testHBoxReference(self):
        #QHBoxLayout.addWidget reference count
        w = QWidget()
        self.checkLayoutReference(QHBoxLayout(w))

    def testVBoxReference(self):
        #QVBoxLayout.addWidget reference count
        w = QWidget()
        self.checkLayoutReference(QVBoxLayout(w))

    def testGridReference(self):
        #QGridLayout.addWidget reference count
        w = QWidget()
        self.checkLayoutReference(QGridLayout(w))

    def testFormReference(self):
        #QFormLayout.addWidget reference count
        w = QWidget()
        self.checkLayoutReference(QFormLayout(w))

    def testStackedReference(self):
        #QStackedLayout.addWidget reference count
        w = QWidget()
        self.checkLayoutReference(QStackedLayout(w))

class MultipleAdd(UsesQApplication):
    '''Test case to check if refcount is incremented only once when multiple
    calls to addWidget are made with the same widget'''

    qapplication = True

    def setUp(self):
        #Acquire resources
        super(MultipleAdd, self).setUp()
        self.widget = QPushButton('click me')
        self.win = QWidget()
        self.layout = QHBoxLayout(self.win)

    def tearDown(self):
        #Release resources
        del self.widget
        del self.layout
        del self.win
        super(MultipleAdd, self).tearDown()

    def testRefCount(self):
        #Multiple QLayout.addWidget calls on the same widget
        self.assertEqual(getrefcount(self.widget), 2)
        self.layout.addWidget(self.widget)
        self.assertEqual(getrefcount(self.widget), 3)
        self.layout.addWidget(self.widget)
        self.assertEqual(getrefcount(self.widget), 3)
        self.layout.addWidget(self.widget)
        self.assertEqual(getrefcount(self.widget), 3)

class InternalAdd(UsesQApplication):
    def testInternalRef(self):
        mw = QWidget()
        w = QWidget()
        ow = QWidget()

        topLayout = QGridLayout()

        # unique reference
        self.assertEqual(getrefcount(w), 2)
        self.assertEqual(getrefcount(ow), 2)

        topLayout.addWidget(w, 0, 0)
        topLayout.addWidget(ow, 1, 0)

        # layout keep the referemce
        self.assertEqual(getrefcount(w), 3)
        self.assertEqual(getrefcount(ow), 3)

        mainLayout = QGridLayout()

        mainLayout.addLayout(topLayout, 1, 0, 1, 4)

        # the same reference
        self.assertEqual(getrefcount(w), 3)
        self.assertEqual(getrefcount(ow), 3)

        mw.setLayout(mainLayout)

        # now trasfer the ownership to mw
        self.assertEqual(getrefcount(w), 3)
        self.assertEqual(getrefcount(ow), 3)

        del mw

        # remove the ref and invalidate the widget
        self.assertEqual(getrefcount(w), 2)
        self.assertEqual(getrefcount(ow), 2)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
'''Unit tests for QSize'''

import unittest

from PySide.QtCore import QSize

class QSizeOperator(unittest.TestCase):
    def testOperatorMultiply(self):
        #QSize operator * float
        # bug 131
        a = QSize(1, 1)
        x = a * 3.4
        self.assertEqual(QSize(3, 3), x)

    def testOperatorRevertedMultiply(self):
        #QSize operator * float, reverted
        # bug 132
        a = QSize(1, 1)
        x = 3.4 * a
        self.assertEqual(QSize(3, 3), x)


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Tests QByteArray implementation of Python buffer protocol'''

import unittest
import py3kcompat as py3k

from os.path import isdir
from PySide.QtCore import QByteArray


class QByteArrayBufferProtocolTest(unittest.TestCase):
    '''Tests QByteArray implementation of Python buffer protocol'''

    def testQByteArrayBufferProtocol(self):
        if py3k.IS_PY3K:
            return
        #Tests QByteArray implementation of Python buffer protocol using the os.path.isdir
        #function which an unicode object or other object implementing the Python buffer protocol
        isdir(QByteArray('/tmp'))

if __name__ == '__main__':
    unittest.main()




import unittest

import os
from helper import UsesQApplication
from PySide.QtCore import QTimer
from PySide.QtGui import QPicture, QPainter, QWidget

class MyWidget(QWidget):
    def paintEvent(self, e):
        p = QPainter(self)
        p.drawPicture(0, 0, self._picture)
        self._app.quit()

class QPictureTest(UsesQApplication):
    def testFromData(self):
        picture = QPicture()
        painter = QPainter()
        painter.begin(picture)
        painter.drawEllipse(10,20, 80,70)
        painter.end()

        data = picture.data()
        picture2 = QPicture()
        picture2.setData(data)

        self.assertEqual(picture2.data(), picture.data())

        w = MyWidget()
        w._picture = picture2
        w._app = self.app

        QTimer.singleShot(300, w.show)
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import Qt, QEvent
from PySide.QtGui import QApplication, QKeyEvent, QKeySequence
import unittest


class TestBug569(unittest.TestCase):

    def testIt(self):
        # We need a qapp otherwise Qt will crash when trying to detect the
        # current platform
        app = QApplication([])
        ev1 = QKeyEvent(QEvent.KeyRelease, Qt.Key_Delete, Qt.NoModifier)
        ev2 = QKeyEvent(QEvent.KeyRelease, Qt.Key_Copy, Qt.NoModifier)
        ks = QKeySequence.Delete

        self.assertEqual(ev1, ks)
        self.assertEqual(ks, ev1)
        self.assertNotEqual(ev2, ks)
        self.assertNotEqual(ks, ev2)

if __name__ == '__main__':
    unittest.main()




'''Connecting lambda to gui signals'''

import unittest

from PySide.QtCore import QObject, SIGNAL

try:
    from PySide.QtGui import QSpinBox, QPushButton
    hasQtGui = True
except ImportError:
    hasQtGui = False

from helper import UsesQApplication

if hasQtGui:
    class Control:
        def __init__(self):
            self.arg = False

    class QtGuiSigLambda(UsesQApplication):

        def testButton(self):
            #Connecting a lambda to a QPushButton.clicked()
            obj = QPushButton('label')
            ctr = Control()
            func = lambda: setattr(ctr, 'arg', True)
            QObject.connect(obj, SIGNAL('clicked()'), func)
            obj.click()
            self.assert_(ctr.arg)
            QObject.disconnect(obj, SIGNAL('clicked()'), func)


        def testSpinButton(self):
            #Connecting a lambda to a QPushButton.clicked()
            obj = QSpinBox()
            ctr = Control()
            arg = 444
            func = lambda x: setattr(ctr, 'arg', 444)
            QObject.connect(obj, SIGNAL('valueChanged(int)'), func)
            obj.setValue(444)
            self.assertEqual(ctr.arg, arg)
            QObject.disconnect(obj, SIGNAL('valueChanged(int)'), func)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QObject.sender()'''

import unittest
from PySide.QtCore import *
from helper import UsesQCoreApplication

class ExtQTimer(QTimer):
    def __init__(self):
        QTimer.__init__(self)

class Receiver(QObject):
    def __init__(self):
        QObject.__init__(self)
        self.the_sender = None

    def callback(self):
        self.the_sender = self.sender()
        if QCoreApplication.instance():
            QCoreApplication.instance().exit()

class ObjectSenderTest(unittest.TestCase):
    '''Test case for QObject.sender() method.'''

    def testSenderPythonSignal(self):
        sender = QObject()
        recv = Receiver()
        QObject.connect(sender, SIGNAL('foo()'), recv.callback)
        sender.emit(SIGNAL('foo()'))
        self.assertEquals(sender, recv.the_sender)

class ObjectSenderCheckOnReceiverTest(unittest.TestCase):
    '''Test case for QObject.sender() method, this one tests the equality on the Receiver object.'''

    def testSenderPythonSignal(self):
        sender = QObject()
        recv = Receiver()
        QObject.connect(sender, SIGNAL('foo()'), recv.callback)
        sender.emit(SIGNAL('foo()'))
        self.assertEquals(sender, recv.the_sender)

class ObjectSenderWithQAppTest(UsesQCoreApplication):
    '''Test case for QObject.sender() method with QApplication.'''

    def testSenderCppSignal(self):
        sender = QTimer()
        sender.setObjectName('foo')
        recv = Receiver()
        QObject.connect(sender, SIGNAL('timeout()'), recv.callback)
        sender.start(10)
        self.app.exec_()
        self.assertEquals(sender, recv.the_sender)

    def testSenderCppSignalSingleShotTimer(self):
        recv = Receiver()
        QTimer.singleShot(10, recv.callback)
        self.app.exec_()
        self.assertTrue(isinstance(recv.the_sender, QObject))

    def testSenderCppSignalWithPythonExtendedClass(self):
        sender = ExtQTimer()
        recv = Receiver()
        QObject.connect(sender, SIGNAL('timeout()'), recv.callback)
        sender.start(10)
        self.app.exec_()
        self.assertEquals(sender, recv.the_sender)

class ObjectSenderWithQAppCheckOnReceiverTest(UsesQCoreApplication):
    '''Test case for QObject.sender() method with QApplication.'''

    def testSenderCppSignal(self):
        sender = QTimer()
        sender.setObjectName('foo')
        recv = Receiver()
        QObject.connect(sender, SIGNAL('timeout()'), recv.callback)
        sender.start(10)
        self.app.exec_()
        self.assertEquals(sender, recv.the_sender)

    def testSenderCppSignalWithPythonExtendedClass(self):
        sender = ExtQTimer()
        recv = Receiver()
        QObject.connect(sender, SIGNAL('timeout()'), recv.callback)
        sender.start(10)
        self.app.exec_()
        self.assertEquals(sender, recv.the_sender)

if __name__ == '__main__':
    unittest.main()




''' Test bug 324: http://bugs.openbossa.org/show_bug.cgi?id=324'''

import unittest
import sys
import signal
from PySide.QtCore import *
from PySide.QtGui import *

class QBug( QObject ):
    def __init__(self, parent = None):
        QObject.__init__(self, parent)

    def check(self):
        self.done.emit("abc")

    done = Signal(str)

class Bug324(unittest.TestCase):

    def on_done(self, val):
        self.value = val

    def testBug(self):
        app = QApplication([])
        bug = QBug()
        self.value = ''
        bug.done.connect(self.on_done)
        bug.check()
        self.assertEqual(self.value, 'abc')

if __name__ == '__main__':
    unittest.main()



from PySide.QtUiTools import QUiLoader
import unittest

from helper import UsesQApplication
from helper import adjust_filename

class MyQUiLoader(QUiLoader):
    def __init__(self):
        super(MyQUiLoader, self).__init__()

    def createWidget(self, className, parent=None, name=""):
        return None

class BugTest(UsesQApplication):
    def testCase(self):
        loader = MyQUiLoader()
        self.assertRaises(RuntimeError, loader.load, adjust_filename('bug_965.ui', __file__))

if __name__ == '__main__':
    unittest.main()



import time
import unittest

from PySide.QtCore import QTime, QRunnable, QThreadPool

class Task(QRunnable):
   def run(self):
       t = QTime()
       t.start()
       time.sleep(2) # Sleep 2 seconds


class QThreadPoolTest(unittest.TestCase):
    '''This used to cause a segfault due the ownership control on globalInstance function '''
    def testSlowJobs(self):
       for i in range(3):
           task = Task()
           QThreadPool.globalInstance().start(task)
           time.sleep(1) # Sleep 1 second

       QThreadPool.globalInstance().waitForDone()

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
import unittest
from PySide.QtMaemo5 import *
from PySide import QtGui

from helper import UsesQApplication

class QtMamo5Test(UsesQApplication):

    def testObjectCreate(self):
        bar = QMaemo5EditBar()
        self.assert_(isinstance(bar, QMaemo5EditBar))

    def testGui(self):
        getattr(QtGui, 'QAbstractKineticScroller')

if __name__ == '__main__':
    unittest.main()





'''Test paint event override in python'''

import unittest

from PySide.QtCore import QTimerEvent
from PySide.QtGui import QApplication, QWidget

from helper import UsesQApplication

class MyWidget(QWidget):
    '''Sample widget'''

    def __init__(self, app=None):
        #Creates a new widget
        if app is None:
            app = QApplication([])

        super(MyWidget, self).__init__()
        self.app = app
        self.runs = 0
        self.max_runs = 5
        self.paint_event_called = False

    def timerEvent(self, event):
        #Timer event method
        self.runs += 1

        if self.runs == self.max_runs:
            self.app.quit()

        if not isinstance(event, QTimerEvent):
            raise TypeError('Invalid event type. Must be QTimerEvent')

    def paintEvent(self, event):
        #Empty paint event method
        # XXX: should be using super here, but somehow PyQt4
        # complains about paintEvent not present in super
        QWidget.paintEvent(self, event)
        self.paint_event_called = True


class PaintEventOverride(UsesQApplication):
    '''Test case for overriding QWidget.paintEvent'''

    qapplication = True

    def setUp(self):
        #Acquire resources
        super(PaintEventOverride, self).setUp()
        self.widget = MyWidget(self.app)

    def tearDown(self):
        #Release resources
        del self.widget
        super(PaintEventOverride, self).tearDown()

    def testPaintEvent(self):
        #Test QWidget.paintEvent override
        timer_id = self.widget.startTimer(100)
        self.widget.show()
        self.app.exec_()

        self.widget.killTimer(timer_id)

        self.assert_(self.widget.paint_event_called)
        self.assertEqual(self.widget.runs, 5)


if __name__ == '__main__':
    unittest.main()



import unittest

from PySide.QtGui import QMatrix4x4

class TestQMatrix(unittest.TestCase):
    def testOperator(self):
        m = QMatrix4x4(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16)
        v = 1
        for x in range(4):
            for y in range(4):
                self.assertEqual(m[x,y], v)
                v += 1

if __name__ == '__main__':
    unittest.main()



""" Unittest for bug #576 """
""" http://bugs.openbossa.org/show_bug.cgi?id=576 """

from PySide import QtGui, QtCore
import sys
import unittest

class Bug576(unittest.TestCase):
    def onButtonDestroyed(self, button):
        self._destroyed = True
        self.assert_(isinstance(button, QtGui.QPushButton))

    def testWidgetParent(self):
        self._destroyed = False
        app = QtGui.QApplication(sys.argv)
        w = QtGui.QWidget()

        b = QtGui.QPushButton("test")
        b.destroyed[QtCore.QObject].connect(self.onButtonDestroyed)
        self.assertEqual(sys.getrefcount(b), 2)
        b.setParent(w)
        self.assertEqual(sys.getrefcount(b), 3)
        b.parent()
        self.assertEqual(sys.getrefcount(b), 3)
        b.setParent(None)
        self.assertEqual(sys.getrefcount(b), 2)
        del b
        self.assert_(self._destroyed)


if __name__ == '__main__':
    unittest.main()




import unittest
import weakref
import sys

from PySide.QtCore import Qt
from PySide.QtGui import QDialog, QLabel, QGridLayout, QHBoxLayout, QWidget

from helper import TimedQApplication

class LabelWindow(QDialog):
    def __init__(self, parent):
        super(LabelWindow, self).__init__(parent)

        self.test_layout = QGridLayout()
        label = QLabel("Label")
        self.test_layout.addWidget(label, 0, 0)
        self.setLayout(self.test_layout)
        self._destroyCalled = False


    def replace(self, unit):
        old_item = self.test_layout.itemAtPosition(0, 0)
        old_label = old_item.widget()
        ref = weakref.ref(old_item, self._destroyed)

        self.test_layout.removeWidget(old_label)
        unit.assertRaises(RuntimeError, old_item.widget)
        del old_item

        label = QLabel("Label New")
        old_label.deleteLater()
        label.setAlignment(Qt.AlignCenter)
        self.test_layout.addWidget(label, 0, 0)

    def _destroyed(self, obj):
        self._destroyCalled = True

class TestBug1006 (TimedQApplication):

    def testLayoutItemLifeTime(self):
        window = LabelWindow(None)
        window.replace(self)
        self.assertTrue(window._destroyCalled)
        self.app.exec_()

    def testParentLayout(self):
        def createLayout():
            label = QLabel()
            layout = QHBoxLayout()
            layout.addWidget(label)

            widget = QWidget()
            widget.setLayout(layout)
            return (layout, widget)
        (layout, widget) = createLayout()
        item = layout.itemAt(0)
        self.assertTrue(isinstance(item.widget(), QWidget))

    def testRemoveOrphanWidget(self):
        widget = QLabel()
        layout = QHBoxLayout()
        layout.addWidget(widget)
        self.assertEqual(sys.getrefcount(widget), 3)

        layout.removeWidget(widget)
        widget.setObjectName("MyWidget")
        self.assertEqual(sys.getrefcount(widget), 2)

    def testRemoveChildWidget(self):
        parent = QLabel()
        widget = QLabel(parent)
        self.assertEqual(sys.getrefcount(widget), 3)

        layout = QHBoxLayout()
        layout.addWidget(widget)
        self.assertEqual(sys.getrefcount(widget), 3)

        layout.removeWidget(widget)
        widget.setObjectName("MyWidget")
        self.assertEqual(sys.getrefcount(widget), 3)

if __name__ == "__main__":
    unittest.main()



import sys
from PySide.QtGui import QLineEdit, QApplication
import unittest


class Bug589(unittest.TestCase):
    def testWrongSignature(self):
        text = QLineEdit("PySide bug 632")
        a = b = c = d = 0
        self.assertRaises(TypeError, text.getTextMargins, (a, b, c, d))

    def testTupleReturn(self):
        text = QLineEdit("PySide bug 632")
        text.setTextMargins(10, 20, 30, 40)
        (a, b, c, d) = text.getTextMargins()
        self.assert_((a, b, c, d), (10, 20, 30, 40))

if __name__ == "__main__":
   app = QApplication(sys.argv)
   unittest.main()



#!/usr/bin/env python

import sys
import unittest
import PySide.QtCore as QtCore

class Signaller(QtCore.QObject):
    s1 = QtCore.Signal()
    s2 = QtCore.Signal()

class TestBug920(unittest.TestCase):

    def testIt(self):
        s = Signaller()
        s.s1.connect(self.onSignal)
        s.s2.connect(self.onSignal)
        self.assertTrue(s.s1.disconnect(self.onSignal))
        self.assertTrue(s.s2.disconnect(self.onSignal))

    def onSignal(self):
        pass


if __name__ == "__main__":
    unittest.main()



import unittest
from PySide.QtCore import Property, QObject
from PySide.QtWebKit import QWebView
from helper import TimedQApplication

class TestLoadFinished(TimedQApplication):

    def setUp(self):
        TimedQApplication.setUp(self, timeout=1000)

    def tearDown(self):
        TimedQApplication.tearDown(self)

    def testQVariantListProperty(self):
        class Obj(object):
            list = ['foo', 'bar', 'baz']

        obj = Obj()

        wrapper_dict = {}
        for name in ['list']:
            getter = lambda arg=None, name=name: getattr(obj, name)
            wrapper_dict[name] = Property('QVariantList', getter)
        wrapper = type('PyObj', (QObject,), wrapper_dict)

        view = QWebView()
        frame = view.page().mainFrame()
        frame.addToJavaScriptWindowObject('py_obj', wrapper())

        html = '''
        <html><body>
        <script type="text/javascript">
        document.write(py_obj.list)
        </script>
        </body></html>
        '''
        view.setHtml(html)
        view.show()
        self.app.exec_()


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

import unittest
from testbinding import TestObject
from PySide.QtCore import QObject, SIGNAL

'''Tests the behaviour of signals with default values.'''

class SignalWithDefaultValueTest(unittest.TestCase):

    def setUp(self):
        self.obj = TestObject(0)
        self.void_called = False
        self.bool_called = False

    def tearDown(self):
        del self.obj
        del self.void_called
        del self.bool_called

    def testConnectNewStyleEmitVoidSignal(self):
        def callbackVoid():
            self.void_called = True
        def callbackBool(value):
            self.bool_called = True
        self.obj.signalWithDefaultValue.connect(callbackVoid)
        self.obj.signalWithDefaultValue[bool].connect(callbackBool)
        self.obj.emitSignalWithDefaultValue_void()
        self.assert_(self.void_called)
        self.assert_(self.bool_called)

    def testConnectNewStyleEmitBoolSignal(self):
        def callbackVoid():
            self.void_called = True
        def callbackBool(value):
            self.bool_called = True
        self.obj.signalWithDefaultValue.connect(callbackVoid)
        self.obj.signalWithDefaultValue[bool].connect(callbackBool)
        self.obj.emitSignalWithDefaultValue_bool()
        self.assert_(self.void_called)
        self.assert_(self.bool_called)

    def testConnectOldStyleEmitVoidSignal(self):
        def callbackVoid():
            self.void_called = True
        def callbackBool(value):
            self.bool_called = True
        QObject.connect(self.obj, SIGNAL('signalWithDefaultValue()'), callbackVoid)
        QObject.connect(self.obj, SIGNAL('signalWithDefaultValue(bool)'), callbackBool)
        self.obj.emitSignalWithDefaultValue_void()
        self.assert_(self.void_called)
        self.assert_(self.bool_called)

    def testConnectOldStyleEmitBoolSignal(self):
        def callbackVoid():
            self.void_called = True
        def callbackBool(value):
            self.bool_called = True
        QObject.connect(self.obj, SIGNAL('signalWithDefaultValue()'), callbackVoid)
        QObject.connect(self.obj, SIGNAL('signalWithDefaultValue(bool)'), callbackBool)
        self.obj.emitSignalWithDefaultValue_bool()
        self.assert_(self.void_called)
        self.assert_(self.bool_called)

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python

import unittest
from PySide.QtCore import *

class ArgsDontMatch(unittest.TestCase):

    def callback(self, arg1):
        self.ok = True

    def testConnectSignalToSlotWithLessArgs(self):
        self.ok = False
        obj1 = QObject()
        QObject.connect(obj1, SIGNAL('the_signal(int, int, int)'), self.callback)
        obj1.emit(SIGNAL('the_signal(int, int, int)'), 1, 2, 3)

        self.assert_(self.ok)



if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QByteArray operators'''

import unittest
import py3kcompat as py3k

from PySide.QtCore import QByteArray

class QByteArrayOperatorEqual(unittest.TestCase):
    '''TestCase for operator QByteArray == QByteArray'''

    def testDefault(self):
        #QByteArray() == QByteArray()
        obj1 = QByteArray()
        obj2 = QByteArray()
        self.assertEqual(obj1, obj2)

    def testSimple(self):
        #QByteArray(some_string) == QByteArray(some_string)
        string = 'egg snakes'
        self.assertEqual(QByteArray(string), QByteArray(string))

    def testPyString(self):
        #QByteArray(string) == string
        string = 'my test string'
        self.assertEqual(QByteArray(string), string)

    def testQString(self):
        #QByteArray(string) == string
        string = 'another test string'
        self.assertEqual(QByteArray(string), string)

class QByteArrayOperatorAt(unittest.TestCase):
    '''TestCase for operator QByteArray[]'''

    def testInRange(self):
        #QByteArray[x] where x is a valid index
        string = 'abcdefgh'
        obj = QByteArray(string)

        for i in range(len(string)):
            self.assertEqual(obj[i], py3k.b(string[i]))

    def testInRangeReverse(self):
        #QByteArray[x] where x is a valid index (reverse order)
        string = 'abcdefgh'
        obj = QByteArray(string)

        for i in range(len(string)-1, 0, -1):
            self.assertEqual(obj[i], py3k.b(string[i]))


    def testOutOfRange(self):
        #QByteArray[x] where x is out of index
        string = '1234567'
        obj = QByteArray(string)
        self.assertRaises(IndexError, lambda :obj[len(string)])

    def testNullStrings(self):
        ba = QByteArray('\x00')
        self.assertEqual(ba.at(0), '\x00')
        self.assertEqual(ba[0], py3k.b('\x00'))

class QByteArrayOperatorLen(unittest.TestCase):
    '''Test case for __len__ operator of QByteArray'''

    def testBasic(self):
        '''QByteArray __len__'''
        self.assertEqual(len(QByteArray()), 0)
        self.assertEqual(len(QByteArray('')), 0)
        self.assertEqual(len(QByteArray(' ')), 1)
        self.assertEqual(len(QByteArray('yabadaba')), 8)


class QByteArrayOperatorStr(unittest.TestCase):
    '''Test case for __str__ operator of QByteArray'''

    def testBasic(self):
        '''QByteArray __str__'''
        self.assertEqual(QByteArray().__str__(), '')
        self.assertEqual(QByteArray('').__str__(), '')
        self.assertEqual(QByteArray('aaa').__str__(), 'aaa')


if __name__ == '__main__':
    unittest.main()




import unittest

from helper import TimedQApplication 

class TestTimedApp(TimedQApplication):
    '''Simple test case for TimedQApplication'''

    def testFoo(self):
        #Simple test of TimedQApplication
        self.app.exec_()

if __name__ == '__main__':
    unittest.main()



import sys
import os
from PySide import QtCore, QtGui
from PySide.QtUiTools import QUiLoader

class Window(object):
    def __init__(self):
        loader = QUiLoader()
        filePath = os.path.join(os.path.dirname(__file__), 'bug_426.ui')
        self.widget = loader.load(filePath)
        self.group = QtGui.QActionGroup(self.widget)
        self.widget.show()
        QtCore.QTimer.singleShot(0, self.widget.close)

if __name__ == "__main__":
    app = QtGui.QApplication(sys.argv)
    win = Window()
    sys.exit(app.exec_())



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QString'''

import unittest
import py3kcompat as py3k
from PySide.QtCore import QObject

class QStringConstructor(unittest.TestCase):
    '''Test case for QString constructors'''

    def testQStringDefault(self):
        obj = QObject()
        obj.setObjectName('foo')
        self.assertEqual(obj.objectName(), py3k.unicode_('foo'))
        obj.setObjectName(py3k.unicode_('áâãà'))
        self.assertEqual(obj.objectName(), py3k.unicode_('áâãà'))
        obj.setObjectName(None)
        self.assertEqual(obj.objectName(), py3k.unicode_(''))

if __name__ == '__main__':
    unittest.main()



''' Test bug 367: http://bugs.openbossa.org/show_bug.cgi?id=367'''

import sys
import unittest
from helper import UsesQApplication
from PySide import QtCore,QtGui

class BugTest(UsesQApplication):
    def testCase(self):
        model = QtGui.QStandardItemModel()
        parentItem = model.invisibleRootItem()
        for i in range(10):
            item = QtGui.QStandardItem()
            rcount =  sys.getrefcount(item)
            parentItem.appendRow(item)
            self.assertEqual(rcount+1, sys.getrefcount(item))
            parentItem = item

        self.assert_(True)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import sys
from PySide.QtCore import QObject, SIGNAL

MAX_LOOPS = 5
MAX_OBJECTS = 200

class Dummy(object):
    def __init__(self, parent):
        self._parent = parent

    def callback(self):
        self._called = True

class MultipleSlots(unittest.TestCase):
    def myCB(self):
        self._count += 1

    """
    def testUnboundSignal(self):
        o = QObject()
        self._count  = 0
        for i in range(MAX_OBJECTS):
            QObject.connect(o, SIGNAL("fire()"), lambda: self.myCB())

        o.emit(SIGNAL("fire()"))
        self.assertEqual(self._count, MAX_OBJECTS)

    """
    def testDisconnectCleanup(self):
        for c in range(MAX_LOOPS):
            self._count = 0
            self._senders = []
            for i in range(MAX_OBJECTS):
                o = QObject()
                QObject.connect(o, SIGNAL("fire()"), lambda: self.myCB())
                self._senders.append(o)
                o.emit(SIGNAL("fire()"))

            self.assertEqual(self._count, MAX_OBJECTS)

            #delete all senders will disconnect the signals
            self._senders = []

if __name__ == '__main__':
    unittest.main()





#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from PySide import QtCore
from helper import UsesQCoreApplication

class Listener(QtCore.QObject):
    def __init__(self):
        QtCore.QObject.__init__(self, None)
        self._phrase = []

    @QtCore.Slot(tuple)
    def listen(self, words):
        for w in words:
            self._phrase.append(w)

class Communicate(QtCore.QObject):
    # create a new signal on the fly and name it 'speak'
    speak = QtCore.Signal(tuple)

class SignaltoSignalTest(UsesQCoreApplication):
    def testBug(self):
        someone = Communicate()
        someone2 = Listener()
        # connect signal and slot
        someone.speak.connect(someone2.listen)
        # emit 'speak' signal
        talk = ("one","two","three")
        someone.speak.emit(talk)
        self.assertEqual(someone2._phrase, list(talk))

if __name__ == '__main__':
    unittest.main()




from PySide.QtGui import QWidget
from PySide.QtCore import QPoint, QTimer, Qt, QEvent
from PySide.QtTest import QTest

import unittest

from helper import UsesQApplication

class MyWidget(QWidget):
    def __init__(self, parent = None):
        QWidget.__init__(self, parent)
        self._sequence = []
        self.setAttribute(Qt.WA_AcceptTouchEvents)
        QTimer.singleShot(200, self.generateEvent)

    def event(self, e):
        self._sequence.append(e.type())
        return QWidget.event(self, e)

    def generateEvent(self):
        o = QTest.touchEvent(self)
        o.press(0, QPoint(10, 10))
        o.commit()
        del o

        QTest.touchEvent(self).press(0, QPoint(10, 10))
        QTest.touchEvent(self).stationary(0).press(1, QPoint(40, 10))
        QTest.touchEvent(self).move(0, QPoint(12, 12)).move(1, QPoint(45, 5))
        QTest.touchEvent(self).release(0, QPoint(12, 12)).release(1, QPoint(45, 5))

        QTimer.singleShot(200, self.deleteLater)


class TouchEventTest(UsesQApplication):
    def testCreateEvent(self):
        w = MyWidget()
        w.show()
        self.app.exec_()
        # same values as C++
        self.assertEqual(w._sequence.count(QEvent.Type.TouchBegin), 2)
        self.assertEqual(w._sequence.count(QEvent.Type.TouchUpdate), 2)
        self.assertEqual(w._sequence.count(QEvent.Type.TouchEnd), 1)


if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import QEvent, Qt
import PySide

import unittest

TEST_EVENT_TYPE = QEvent.Type(QEvent.registerEventType())

class TestEvent(QEvent):
    TestEventType = QEvent.Type(QEvent.registerEventType())

    def __init__(self, rand=0):
        super(TestEvent, self).__init__(TestEvent.TestEventType)
        self._rand = rand

    def getRand(self):
        return self._rand


class TestEnums(unittest.TestCase):
    def testUserTypesValues(self):
        self.assert_(QEvent.User <= int(TestEvent.TestEventType) <= QEvent.MaxUser)
        self.assert_(QEvent.User <= int(TEST_EVENT_TYPE) <= QEvent.MaxUser)

    def testUserTypesRepr(self):
        self.assertEqual(eval(repr(TestEvent.TestEventType)), TestEvent.TestEventType)
        self.assertEqual(eval(repr(TEST_EVENT_TYPE)), TEST_EVENT_TYPE)

if __name__ == '__main__':
    unittest.main()



import unittest
import py3kcompat as py3k
from PySide.QtGui import QStandardItemModel, QStandardItem

class MyItemModel(QStandardItemModel):
    def __init__(self,parent=None):
        super(MyItemModel,self).__init__(parent)
        self.appendRow([QStandardItem('Item 1'),])

    def mimeTypes(self):
        mtypes = super(MyItemModel,self).mimeTypes()
        mtypes.append(py3k.unicode_('application/my-form'))
        return mtypes

    def mimeData(self,indexes):
        self.__mimedata = super(MyItemModel,self).mimeData(indexes)
        self.__mimedata.setData(py3k.unicode_('application/my-form'), 'hi')
        return self.__mimedata

class TestBug660(unittest.TestCase):
    '''QMimeData type deleted prematurely when overriding mime-type in QStandardItemModel drag and drop'''
    def testIt(self):
        model = MyItemModel()
        model.mimeData([model.index(0, 0)]) # if it doesn't raise an exception it's all right!

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Test cases for QObject methods'''

import unittest
import py3kcompat as py3k

from PySide.QtCore import QObject

class ObjectNameCase(unittest.TestCase):
    '''Tests related to QObject object name'''

    def testSimple(self):
        #QObject.objectName(string)
        name = 'object1'
        obj = QObject()
        obj.setObjectName(name)

        self.assertEqual(name, obj.objectName())

    def testEmpty(self):
        #QObject.objectName('')
        name = ''
        obj = QObject()
        obj.setObjectName(name)

        self.assertEqual(name, obj.objectName())

    def testDefault(self):
        #QObject.objectName() default
        obj = QObject()
        self.assertEqual('', obj.objectName())

    def testUnicode(self):
        name = py3k.unicode_('não')
        #FIXME Strange error on upstream when using equal(name, obj)
        obj = QObject()
        obj.setObjectName(name)
        self.assertEqual(obj.objectName(), name)


if __name__ == '__main__':
    unittest.main()



import unittest
import sys

from PySide.QtCore import QObject, SIGNAL, QUrl
from PySide.QtWebKit import *
from PySide.QtNetwork import QNetworkRequest

from helper import adjust_filename, UsesQApplication



class TestWebFrame(UsesQApplication):
    def load_finished(self, ok):
        self.assert_(ok)
        page = self.view.page()
        self.assert_(page)
        frame = page.mainFrame()
        self.assert_(frame)
        meta = frame.metaData()
        self.assertEqual(meta['description'], ['PySide Test METADATA.'])
        self.app.quit()

    def testMetaData(self):
        self.view = QWebView()
        QObject.connect(self.view, SIGNAL('loadFinished(bool)'),
                        self.load_finished)
        url = QUrl.fromLocalFile(adjust_filename('fox.html', __file__))
        self.view.setUrl(url)
        self.app.exec_()


if __name__ == '__main__':
    unittest.main()




from PySide.QtCore import QAbstractFileEngine, QIODevice, QFile
import unittest
import tempfile
import os
import py3kcompat as py3k

class TestBug724 (unittest.TestCase):

    def testIt(self):
        # creates a temporary file
        handle, self.filename = tempfile.mkstemp()
        os.write(handle, py3k.b('a'))
        os.close(handle)

        engine = QAbstractFileEngine.create(self.filename)
        engine.open(QIODevice.ReadOnly)
        memory = engine.map(0, 1, QFile.NoOptions)
        self.assertEqual(len(memory), 1)
        self.assertEqual(memory[0], py3k.b('a'))
        engine.unmap(memory)

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
import sys

app = QApplication(sys.argv)
scene = QGraphicsScene()
label = QLabel("hello world")
label.show()
QTimer.singleShot(0, label.close)
exit(app.exec_())



#!/usr/bin/python
# -*- coding: utf-8 -*-
'''Tests conversions of QString to and from QKeySequence.'''

import unittest
import py3kcompat as py3k
from helper import UsesQApplication

from PySide.QtGui import QKeySequence, QAction

class QStringQKeySequenceTest(UsesQApplication):
    '''Tests conversions of QString to and from QKeySequence.'''

    def testQStringFromQKeySequence(self):
        '''Creates a QString from a QKeySequence.'''
        keyseq = 'Ctrl+A'
        a = QKeySequence(keyseq)
        self.assertEqual(a, keyseq)

    def testPythonStringAsQKeySequence(self):
        '''Passes a Python string to an argument expecting a QKeySequence.'''
        keyseq = py3k.unicode_('Ctrl+A')
        action = QAction(None)
        action.setShortcut(keyseq)
        shortcut = action.shortcut()
        self.assert_(isinstance(shortcut, QKeySequence))
        self.assertEqual(shortcut.toString(), keyseq)

if __name__ == '__main__':
    unittest.main()





import unittest

from PySide.QtGui import QToolBox, QWidget, QIcon

from helper import UsesQApplication

class OwnershipControl(UsesQApplication):

    def setUp(self):
        super(OwnershipControl, self).setUp()
        self.toolbox = QToolBox()

    def tearDown(self):
        del self.toolbox
        super(OwnershipControl, self).tearDown()

    def testAddItem(self):
        # Was losing ownership of the widget.
        index = self.toolbox.addItem(QWidget(), 'item')
        item = self.toolbox.widget(index)
        self.assert_(isinstance(item, QWidget))

    def testAddItemWithIcon(self):
        index = self.toolbox.addItem(QWidget(), QIcon(), 'item')
        item = self.toolbox.widget(index)
        self.assert_(isinstance(item, QWidget))


if __name__ == '__main__':
    unittest.main()



'''Test cases for QDeclarativeNetwork'''

import unittest

from PySide.QtCore import QUrl
from PySide.QtDeclarative import QDeclarativeView, QDeclarativeNetworkAccessManagerFactory
from PySide.QtNetwork import QNetworkAccessManager

from helper import adjust_filename, TimedQApplication

class TestQDeclarativeNetworkFactory(TimedQApplication):

    def setUp(self):
        TimedQApplication.setUp(self, timeout=1000)

    def testQDeclarativeNetworkFactory(self):
        view = QDeclarativeView()

        url = QUrl.fromLocalFile(adjust_filename('hw.qml', __file__))

        view.setSource(url)
        view.show()

        self.assertEqual(view.status(), QDeclarativeView.Ready)

        self.app.exec_()

if __name__ == '__main__':
    unittest.main()




''' Test case for QObject.signalsBlocked() and blockSignal()'''

import unittest
import os
from tempfile import mkstemp

from PySide.QtCore import QObject, SIGNAL, QFile, QThread, QTimer, Qt
from helper import UsesQCoreApplication

class MyThread(QThread):

    def run(self):
        self.emit(SIGNAL("test(const QString&)"), "INdT - PySide");

class TestThreadSignal(UsesQCoreApplication):

    __called__ = True
    def _callback(self, msg):
        self.assertEqual(msg, "INdT - PySide")
        self.__called__ = True
        self.app.quit()

    def testThread(self):
        t = MyThread()
        QObject.connect(t, SIGNAL("test(const QString&)"), self._callback);
        t.start()

        self.app.exec_()
        t.wait()
        self.assert_(self.__called__);

if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtCore import *
from PySide.QtGui import *

class MyDiagram(QGraphicsScene):
    pass

class MyItem(QGraphicsRectItem):
    def itemChange(self, change, value):
        return value;

class QGraphicsSceneOnQVariantTest(unittest.TestCase):
    """Test storage ot QGraphicsScene into QVariants"""
    def testIt(self):
        app = QApplication([])
        s = MyDiagram()
        i = MyItem()
        s.addItem(i)
        self.assertEqual(len(s.items()), 1)

if __name__ == '__main__':
    unittest.main()



from PySide.QtCore import *
from PySide.QtGui import *
import unittest

class TestBugPYSIDE42 (unittest.TestCase):

    def testIt(self):
        obj1 = QFile()
        obj2 = QObject()
        hash1 = hash(obj1)
        hash2 = hash(obj2)

        self.assertNotEqual(hash1, hash2)
        self.assertEqual(hash1, hash(obj1))

if __name__ == '__main__':
    unittest.main()




import unittest

from PySide.QtCore import QObject, QTimer, QThread
from PySide.QtGui import *

class Foo(QTableView):
    def __init__(self, parent=None):
        QTableView.__init__(self, parent)

from helper import UsesQApplication

class TestParentType(UsesQApplication):

    def testParentType(self):
        # Test the problem with calling QObject.parent from a QWidget
        # when the parent is a python class derived from a QWidget-derived
        # class. The method was returning the last C++ class in the hierarchy
        parent = Foo()
        w2 = QWidget(parent)
        self.assert_(isinstance(w2.parentWidget(), Foo))
        self.assert_(isinstance(w2.parent(), Foo))

if __name__ == '__main__':
    unittest.main()



import unittest
import sys

from PySide import QtGui
from PySide import QtCore

from helper import TimedQApplication

class TestFontDialog(TimedQApplication):

    def testGetFont(self):
        QtGui.QFontDialog.getFont()

    def testGetFontQDialog(self):
        QtGui.QFontDialog.getFont(QtGui.QFont("FreeSans",10))
    
    def testGetFontQDialogQString(self):
        QtGui.QFontDialog.getFont(QtGui.QFont("FreeSans",10), None, "Select font")

if __name__ == '__main__':
    unittest.main()




#!/usr/bin/python
'''Unit tests for QByteArray'''

import unittest
import ctypes
import pickle
import py3kcompat as py3k

from PySide.QtCore import QByteArray, QSettings, QObject

class QByteArrayTestToNumber(unittest.TestCase):
    def testToNumberInt(self):
        obj = QByteArray('37')
        self.assertEqual((37, True), obj.toInt())

    def testToNumberUShort(self):
        obj = QByteArray('37')
        self.assertEqual((37, True), obj.toUShort())

    def testToNumberFloat(self):
        obj = QByteArray('37.109')
        self.assertEqual((ctypes.c_float(37.109).value, True),
                         obj.toFloat())

    def testToNumberDouble(self):
        obj = QByteArray('37.109')
        self.assertEqual((ctypes.c_double(37.109).value, True),
                         obj.toDouble())

    def testSetNum(self):
        b = QByteArray()
        b.setNum(py3k.long(-124124))
        self.assertEqual(b, "-124124")
        b = QByteArray()
        b.setNum(-124124)
        self.assertEqual(b, "-124124")
        b = QByteArray()
        b.setNum(-0.5)
        self.assertEqual(b, "-0.5")

    def testAppend(self):
        b = QByteArray()
        b.append("A")
        self.assertEqual(b.size(), 1)
        b.append("AB")
        self.assertEqual(b.size(), 3)


class QByteArraySplit(unittest.TestCase):
    '''Test case for QByteArray.split'''

    def testPathSeparator(self):
        #QByteArray.split('/')
        obj = QByteArray(unittest.__file__)
        self.assertEqual(obj.split('/'), unittest.__file__.split('/'))

class QByteArrayData(unittest.TestCase):

    '''Test case for QByteArray.data'''

    def testData(self):
        url = QByteArray("http://web.openbossa.org/")
        self.assertEqual(url.data(), py3k.b("http://web.openbossa.org/"))

    def testDataWithZeros(self):
        s1 = "123\000321"
        ba = QByteArray(s1)
        s2 = ba.data()
        self.assertEqual(py3k.b(s1), s2)
        self.assertEqual(s1, ba)

class QByteArrayOperatorAtSetter(unittest.TestCase):
    '''Test case for operator QByteArray[] - __setitem__'''

    def testSetterString(self):
        '''QByteArray[x] = pythonstring'''
        obj = QByteArray('123456')
        obj[1] = '0'
        self.assertEqual(obj, QByteArray('103456'))

    def testSetterStringLarge(self):
        '''QByteArray[x] = pythonstring (larget than 1 char)'''
        obj = QByteArray('123456')
        obj[3] = 'abba'
        self.assertEqual(obj, QByteArray('123abba56'))

    def testSetterQByteArray(self):
        '''QByteArray[x] = qbytearray'''
        obj = QByteArray('123456')
        obj[3] = QByteArray('array')
        self.assertEqual(obj, QByteArray('123array56'))


class QByteArrayOperatorAtSetterNegativeIndex(unittest.TestCase):
    '''Test case for QByteArray[] - __setitem__ - for negative index'''

    def testSetterNegativeIndex(self):
        '''QByteArray[x] = string - negative index'''
        obj = QByteArray('123456')
        obj[-3] = 'array'
        self.assertEqual(obj, QByteArray('123array56'))


class QByteArrayOperatorAtSetterLargeIndex(unittest.TestCase):
    '''Test case for QByteArray[] - __setitem__ - for 'overflown' index'''

    def testSetterLargeIndexEmpty(self):
        '''QByteArray[x] = somestring - Overflow index on empty string'''
        # should pad with spaces if the index is larger
        obj = QByteArray('')
        obj[2] = 'a'
        self.assertEqual(obj, QByteArray('  a'))

    def testSetterLargeIndexNormal(self):
        '''QByteArray[x] = somestring - Overflow index on normal string'''
        # should pad with spaces if the index is larger
        obj = QByteArray('mystring')
        obj[10] = 'normal'
        self.assertEqual(obj, QByteArray('mystring  normal'))

class QByteArrayOnQVariant(unittest.TestCase):
    def testQByteArrayOnQVariant(self):
        a = QSettings().value("some_prop", QByteArray())
        self.assertEqual(type(a), QByteArray)

class TestBug666(unittest.TestCase):
    '''QByteArray does not support slices'''
    def testIt(self):
        if not py3k.IS_PY3K:
            ba = QByteArray('1234567890')
            self.assertEqual(ba[2:4], '34')
            self.assertEqual(ba[:4], '1234')
            self.assertEqual(ba[4:], '567890')
            self.assertEqual(len(ba[4:1]), 0)

class QByteArrayBug514(unittest.TestCase):
    def testIt(self):
        data = py3k.b("foobar")
        a = QByteArray.fromRawData(data)
        self.assertEqual(type(a), QByteArray)
        self.assertEqual(a.data(), data)

class TestPickler(unittest.TestCase):
    def testIt(self):
        ba = QByteArray("321\x00123")
        output = pickle.dumps(str(ba))
        ba2 = pickle.loads(output)
        self.assertEqual(ba, ba2)

class QByteArrayBug720(unittest.TestCase):
    def testIt(self):
        ba = QByteArray(b"32\"1\x00123")
        self.assertEqual(str(ba), "32\"1\x00123")
        self.assertEqual(repr(ba), "PySide.QtCore.QByteArray('32\"1\x00123')")

class QByteArrayImplicitConvert(unittest.TestCase):
    def testString(self):
        # No implicit conversions from QByteArray to python string
        ba = QByteArray("object name")
        obj = QObject()
        self.assertRaises(TypeError, obj.setObjectName, ba)


if __name__ == '__main__':
    unittest.main()



import unittest
import sys
import weakref

from PySide import QtGui
from PySide import QtCore

from helper import UsesQApplication

class MainWindow(QtGui.QMainWindow):
    def __init__(self):
        QtGui.QMainWindow.__init__(self)

        self.createToolbar()

    def createToolbar(self):
        pointerButton = QtGui.QToolButton()
        pointerToolbar = self.addToolBar("Pointer type")
        pointerToolbar.addWidget(pointerButton)

class MyButton(QtGui.QPushButton):
    def __init__(self, parent=None):
        QtGui.QPushButton.__init__(self)
        self._called = False

    def myCallback(self):
        self._called = True


class TestMainWindow(UsesQApplication):

    def testCreateToolbar(self):
        w = MainWindow()
        w.show()
        QtCore.QTimer.singleShot(1000, self.app.quit)
        self.app.exec_()

    def objDel(self, obj):
        self.app.quit()

    def testRefCountToNull(self):
        w = QtGui.QMainWindow()
        c = QtGui.QWidget()
        self.assertEqual(sys.getrefcount(c), 2)
        w.setCentralWidget(c)
        self.assertEqual(sys.getrefcount(c), 3)
        wr = weakref.ref(c, self.objDel)
        w.setCentralWidget(None)
        c = None
        self.app.exec_()

    def testRefCountToAnother(self):
        w = QtGui.QMainWindow()
        c = QtGui.QWidget()
        self.assertEqual(sys.getrefcount(c), 2)
        w.setCentralWidget(c)
        self.assertEqual(sys.getrefcount(c), 3)

        c2 = QtGui.QWidget()
        w.setCentralWidget(c2)
        self.assertEqual(sys.getrefcount(c2), 3)

        wr = weakref.ref(c, self.objDel)
        w.setCentralWidget(None)
        c = None

        self.app.exec_()

    def testSignalDisconect(self):
        w = QtGui.QMainWindow()
        b = MyButton("button")
        b.clicked.connect(b.myCallback)
        w.setCentralWidget(b)

        b = MyButton("button")
        b.clicked.connect(b.myCallback)
        w.setCentralWidget(b)

        b.click()
        self.assertEqual(b._called, True)


if __name__ == '__main__':
    unittest.main()




import unittest
from PySide.QtGui import *

class TestBug967 (unittest.TestCase):

    def callback(self, arg):
        self.arg = arg

    def testIt(self):
        self.arg = None
        app = QApplication([])
        obj = QComboBox()
        obj.currentIndexChanged.connect(self.callback)
        obj.currentIndexChanged.emit(5)
        self.assertEqual(self.arg, 5)

if __name__ == "__main__":
    unittest.main()



'''Test cases for QTextEdit and ownership problems.'''

import unittest
from sys import getrefcount
from PySide.QtGui import QTextEdit

from helper import UsesQApplication

class DontTouchReference(UsesQApplication):
    '''Check if the QTextTable returned by QTextCursor.insertTable() is not
    referenced by the QTextCursor that returns it.'''

    def setUp(self):
        super(DontTouchReference, self).setUp()
        self.editor = QTextEdit()
        self.cursor = self.editor.textCursor()
        self.table = self.cursor.insertTable(1, 1)

    def testQTextTable(self):
        # methods which return QTextTable should not increment its reference
        self.assertEqual(getrefcount(self.table), 2)
        f = self.cursor.currentFrame()
        del f
        self.assertEqual(getrefcount(self.table), 2)
        # destroying the cursor should not raise any "RuntimeError: internal
        # C++ object already deleted." when accessing the QTextTable
        del self.cursor
        self.assertEqual(getrefcount(self.table), 2)
        cell = self.table.cellAt(0, 0)

if __name__ == "__main__":
    unittest.main()



''' Test bug 512: http://bugs.openbossa.org/show_bug.cgi?id=512'''

import unittest
from helper import UsesQApplication
from PySide.QtCore import *
from PySide.QtGui import *

class BugTest(UsesQApplication):
    def testCase(self):
        w = QWidget(None)
        lbl = QLabel("Hello", w);
        g = QGridLayout()
        g.addWidget(lbl, 0, 0)
        w.setLayout(g)
        w.show()

        t = g.getItemPosition(0)
        self.assertEqual(type(t), tuple)
        self.assertEqual(t, (0,0,1,1))

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import unittest
from helper import adjust_filename

from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtUiTools import *

class TestBug913 (unittest.TestCase):

    def testIt(self):
        app = QApplication([])

        loader = QUiLoader()
        widget = loader.load(adjust_filename('bug_913.ui', __file__))
        widget.tabWidget.currentIndex() # direct child is available as member
        widget.le_first.setText('foo') # child of QTabWidget must also be available!

if __name__ == '__main__':
    unittest.main()



'''Test cases for QVariant::Type converter'''
import unittest
import py3kcompat as py3k
from PySide.QtSql import QSqlField

class QVariantTypeTest(unittest.TestCase):
    def testQVariantType(self):
        f = QSqlField("name", str)
        self.assertEqual(f.type(), py3k.unicode)

        f = QSqlField("name", "QString")
        self.assertEqual(f.type(),  py3k.unicode)

        f = QSqlField("name", "double")
        self.assertEqual(f.type(), float)

        f = QSqlField("name", float)
        self.assertEqual(f.type(), float)

        f = QSqlField("name", int)
        self.assertEqual(f.type(), int)

        if not py3k.IS_PY3K:
            f = QSqlField("name", long)
            self.assertEqual(f.type(), int) # long isn't registered in QVariant:Type, just in QMetaType::Type

        #f = QSqlField("name", QObject)
        #self.assertEqual(f.type(), None)

        f = QSqlField("name", None)
        self.assertEqual(f.type(), None)

if __name__ == '__main__':
    unittest.main()



import sys
import unittest
from PySide.QtCore import *
from PySide.QtGui import *
from PySide.QtWebKit import *

class ErrorPage (QWebPage):

    def __init__(self):
        QWebPage.__init__(self)
        self.rcv_extension = None
        self.rcv_url = None
        self.rcv_url_copy = None
        self.rcv_option_type = None
        self.rcv_output_type = None


    def supportsExtension(self, extension):
        return extension == QWebPage.ErrorPageExtension

    def extension(self, extension, option, output):
        self.rcv_extension = extension
        self.rcv_url = option.url
        self.rcv_url_copy = QUrl(option.url)
        self.rcv_option_type = type(option)
        self.rcv_output_type = type(output)
        return True

class TestWebPageExtension(unittest.TestCase):
    def testIt(self):
        app = QApplication([])
        ep = ErrorPage()
        view = QWebView()
        view.setPage(ep)
        view.load("foo://bar") # Some malformmed url
        view.show()

        # If the timeout is 0 the webpage isn't even loaded on Qt4.6-i386, so we use 100 :-)
        QTimer.singleShot(100, app.quit)
        app.exec_()

        self.assertEqual(ep.rcv_extension, QWebPage.ErrorPageExtension)
        self.assertRaises(RuntimeError, ep.rcv_url.__str__)

        self.assertEqual(ep.rcv_url_copy, "foo://bar")
        self.assertEqual(ep.rcv_option_type, QWebPage.ErrorPageExtensionOption)
        self.assertEqual(ep.rcv_output_type, QWebPage.ErrorPageExtensionReturn)

if __name__ == '__main__':
    unittest.main()
